@@ -38,14 +38,23 @@ def plot_image_spectra(
     A utility function to extract and plot image spectra.
 
     :param input_img: is the input image
-    :param vec_file: is the region of interest file as a vector file - if multiple polygons are defined the spectra for each will be added to the plot.
-    :param vec_lyr:
-    :param output_plot_file: is the output PDF file for the plot which has been create
-    :param wavelengths: is list of numbers with the wavelength of each band (must have the same number of wavelengths as image bands)
+    :param vec_file: is the region of interest as a vector file -
+                     if multiple polygons are defined the spectra for each
+                     will be added to the plot.
+    :param vec_lyr: is the region of interest vector layer
+    :param output_plot_file: is the output image file for the plot
+                             which has been create
+    :param wavelengths: is list of numbers with the wavelength of each band
+                        (must have the same number of wavelengths as image bands)
     :param plot_title: is a string with the title for the plot
-    :param scale_factor: is a float specifying the scaling to percentage (0 - 100). (Default is 0.1, i.e., pixel values are scaled between 0-1000; ARCSI default).
-    :param show_refl_std: is a boolean (default: True) to specify whether a shaded region showing 1 standard deviation from the mean on the plot alongside the mean spectra.
-    :param refl_max: is a parameter for setting the maximum reflectance value on the Y axis (if None the maximum value in the dataset is used
+    :param scale_factor: is a float specifying the scaling to percentage (0 - 100).
+                         (Default is 0.1, i.e., pixel values are scaled between 0-1000;
+                         ARCSI default).
+    :param show_refl_std: is a boolean (default: True) to specify whether a shaded
+                          region showing 1 standard deviation from the mean on the
+                          plot alongside the mean spectra.
+    :param refl_max: is a parameter for setting the maximum reflectance value on
+                     the Y axis (if None the maximum value in the dataset is used
 
     .. code:: python
 
@@ -63,10 +72,10 @@ def plot_image_spectra(
     import rsgislib.tools.filetools
 
     dataset = gdal.Open(input_img, gdal.GA_ReadOnly)
-    numBands = dataset.RasterCount
+    num_bands = dataset.RasterCount
     dataset = None
 
-    if not len(wavelengths) == numBands:
+    if not len(wavelengths) == num_bands:
         raise rsgislib.RSGISPyException(
             "The number of wavelengths and image bands must be equal."
         )
@@ -94,46 +103,46 @@ def plot_image_spectra(
         False,
     )
 
-    meanVals = []
-    stdDevVals = []
+    mean_vals = []
+    std_dev_vals = []
     stats = open(tmpOutFile, "r")
     row = 0
-    for statsRow in stats:
-        statsRow = statsRow.strip()
+    for stats_row in stats:
+        stats_row = stats_row.strip()
         if row > 0:
-            meanVal = []
-            stdDevVal = []
-            data = statsRow.split(",")
+            mean_val = []
+            std_dev_val = []
+            data = stats_row.split(",")
 
-            if not len(data) == (numBands * 2) + 2:
+            if not len(data) == (num_bands * 2) + 2:
                 raise rsgislib.RSGISPyException(
                     "The number of outputted stats values is incorrect!"
                 )
-            for band in range(numBands):
-                meanVal.append(float(data[(band * 2) + 1]) * scale_factor)
-                stdDevVal.append(float(data[(band * 2) + 2]) * scale_factor)
-            meanVals.append(meanVal)
-            stdDevVals.append(stdDevVal)
+            for band in range(num_bands):
+                mean_val.append(float(data[(band * 2) + 1]) * scale_factor)
+                std_dev_val.append(float(data[(band * 2) + 2]) * scale_factor)
+            mean_vals.append(mean_val)
+            std_dev_vals.append(std_dev_val)
         row += 1
     stats.close()
 
-    # print("Mean: ", meanVals)
-    # print("Std Dev: ", stdDevVals)
+    # print("Mean: ", mean_vals)
+    # print("Std Dev: ", std_dev_vals)
     print("Creating Plot")
     fig = plt.figure(figsize=(7, 5), dpi=80)
     ax1 = fig.add_subplot(111)
-    for feat in range(len(meanVals)):
-        ax1.plot(wavelengths, meanVals[feat], "k-", zorder=10)
+    for feat in range(len(mean_vals)):
+        ax1.plot(wavelengths, mean_vals[feat], "k-", zorder=10)
         if show_refl_std:
-            lowerVals = []
-            upperVals = []
-            for band in range(numBands):
-                lowerVals.append(meanVals[feat][band] - stdDevVals[feat][band])
-                upperVals.append(meanVals[feat][band] + stdDevVals[feat][band])
+            lower_vals = []
+            upper_vals = []
+            for band in range(num_bands):
+                lower_vals.append(mean_vals[feat][band] - std_dev_vals[feat][band])
+                upper_vals.append(mean_vals[feat][band] + std_dev_vals[feat][band])
             ax1.fill_between(
                 wavelengths,
-                lowerVals,
-                upperVals,
+                lower_vals,
+                upper_vals,
                 alpha=0.2,
                 linewidth=1.0,
                 facecolor=[0.70, 0.70, 0.70],
@@ -141,12 +150,12 @@ def plot_image_spectra(
                 zorder=-1,
             )
 
-    ax1Range = ax1.axis("tight")
+    ax1_range = ax1.axis("tight")
 
     if refl_max is None:
-        ax1.axis((ax1Range[0], ax1Range[1], 0, ax1Range[3]))
+        ax1.axis((ax1_range[0], ax1_range[1], 0, ax1_range[3]))
     else:
-        ax1.axis((ax1Range[0], ax1Range[1], 0, refl_max))
+        ax1.axis((ax1_range[0], ax1_range[1], 0, refl_max))
 
     plt.grid(color="k", linestyle="--", linewidth=0.5)
     plt.title(plot_title)
@@ -159,50 +168,65 @@ def plot_image_spectra(
 
 
 def plot_image_comparison(
-    inputImage1,
-    inputImage2,
-    img1Band,
-    img2Band,
-    outputPlotFile,
-    numBins=100,
-    img1Min=None,
-    img1Max=None,
-    img2Min=None,
-    img2Max=None,
-    img1Scale=1,
-    img2Scale=1,
-    img1Off=0,
-    img2Off=0,
-    normOutput=False,
-    plotTitle="2D Histogram",
-    xLabel="X Axis",
-    yLabel="Y Axis",
+    input_image1,
+    input_image2,
+    img1_band,
+    img2_band,
+    output_plot_file,
+    num_bins=100,
+    img1_min=None,
+    img1_max=None,
+    img2_min=None,
+    img2_max=None,
+    img1_scale=1,
+    img2_scale=1,
+    img1_off=0,
+    img2_off=0,
+    norm_output=False,
+    plot_title="2D Histogram",
+    x_label="X Axis",
+    y_label="Y Axis",
     ctable="jet",
     interp="nearest",
 ):
     """
     A function to plot two images against each other.
 
-    :param inputImage1: is a string with the path to the first image.
-    :param inputImage2: is a string with the path to the second image.
-    :param img1Band: is an int specifying the band in the first image to be plotted.
-    :param img2Band: is an int specifying the band in the second image to be plotted.
-    :param outputPlotFile: is a string specifying the output PDF for the plot.
-    :param numBins: is an int specifying the number of bins within each axis of the histogram (default: 100)
-    :param img1Min: is a double specifying the minimum value to be used in the histogram from image 1. If value is None then taken from the image.
-    :param img1Max: is a double specifying the maximum value to be used in the histogram from image 1. If value is None then taken from the image.
-    :param img2Min: is a double specifying the minimum value to be used in the histogram from image 2. If value is None then taken from the image.
-    :param img2Max: is a double specifying the maximum value to be used in the histogram from image 2. If value is None then taken from the image.
-    :param img1Scale: is a double specifying the scale for image 1 (Default 1).
-    :param img2Scale: is a double specifying the scale for image 2 (Default 1).
-    :param img1Off: is a double specifying the offset for image 1 (Default 0).
-    :param img2Off: is a double specifying the offset for image 2 (Default 0).
-    :param normOutput: is a boolean specifying whether the histogram should be normalised (Default: False).
-    :param plotTitle: is a string specifying the title of the plot (Default: '2D Histogram').
-    :param xLabel: is a string specifying the x axis label (Default: 'X Axis')
-    :param yLabel: is a string specifying the y axis label (Default: 'Y Axis')
-    :param ctable: is a string specifying the colour table to be used (Default: jet), list of available colour tables specified by matplotlib: http://matplotlib.org/examples/color/colormaps_reference.html
-    :param interp: is a string specifying the interpolation algorithm to be used (Default: 'nearest'). Available values are ‘none’, ‘nearest’, ‘bilinear’, ‘bicubic’, ‘spline16’, ‘spline36’, ‘hanning’, ‘hamming’, ‘hermite’, ‘kaiser’, ‘quadric’, ‘catrom’, ‘gaussian’, ‘bessel’, ‘mitchell’, ‘sinc’, ‘lanczos’.
+    :param input_image1: is a string with the path to the first image.
+    :param input_image2: is a string with the path to the second image.
+    :param img1_band: is an int specifying the band in the first image to be plotted.
+    :param img2_band: is an int specifying the band in the second image to be plotted.
+    :param output_plot_file: is a string specifying the output image file for the plot.
+                             Note, the output format is defined using the image
+                             extension. (e.g., img.png would output a PNG image).
+    :param num_bins: is an int specifying the number of bins within each axis of the
+                     histogram (default: 100)
+    :param img1_min: is a double specifying the minimum value to be used in the
+                     histogram from image 1. If value is None then taken from the image.
+    :param img1_max: is a double specifying the maximum value to be used in the
+                     histogram from image 1. If value is None then taken from the image.
+    :param img2_min: is a double specifying the minimum value to be used in the
+                     histogram from image 2. If value is None then taken from the image.
+    :param img2_max: is a double specifying the maximum value to be used in the
+                     histogram from image 2. If value is None then taken from the image.
+    :param img1_scale: is a double specifying the scale for image 1 (Default 1).
+    :param img2_scale: is a double specifying the scale for image 2 (Default 1).
+    :param img1_off: is a double specifying the offset for image 1 (Default 0).
+    :param img2_off: is a double specifying the offset for image 2 (Default 0).
+    :param norm_output: is a boolean specifying whether the histogram should be
+                        normalised (Default: False).
+    :param plot_title: is a string specifying the title of the plot
+                       (Default: '2D Histogram').
+    :param x_label: is a string specifying the x axis label (Default: 'X Axis')
+    :param y_label: is a string specifying the y axis label (Default: 'Y Axis')
+    :param ctable: is a string specifying the colour table to be used (Default: jet),
+                   list of available colour tables specified by matplotlib:
+                   http://matplotlib.org/examples/color/colormaps_reference.html
+    :param interp: is a string specifying the interpolation algorithm to be used
+                   (Default: 'nearest'). Available values are ‘none’, ‘nearest’,
+                   ‘bilinear’, ‘bicubic’, ‘spline16’, ‘spline36’, ‘hanning’,
+                   ‘hamming’, ‘hermite’, ‘kaiser’, ‘quadric’, ‘catrom’, ‘gaussian’,
+                   ‘bessel’, ‘mitchell’, ‘sinc’, ‘lanczos’.
 
     .. code:: python
 
@@ -216,117 +240,116 @@ def plot_image_comparison(
 
     """
     gdalformat = "KEA"
-    tmpOutFile = os.path.splitext(outputPlotFile)[0] + "_hist2dimgtmp.kea"
-    # tmpOutFileStch = os.path.splitext(outputPlotFile)[0] + "_hist2dimgtmpStch.kea"
+    tmp_out_file = os.path.splitext(output_plot_file)[0] + "_hist2dimgtmp.kea"
 
-    if (img1Min is None) or (img1Max is None):
+    if (img1_min is None) or (img1_max is None):
         # Calculate image 1 stats
-        imgGDALDS = gdal.Open(inputImage1, gdal.GA_ReadOnly)
-        imgGDALBand = imgGDALDS.GetRasterBand(img1Band)
-        min, max = imgGDALBand.ComputeRasterMinMax(False)
-        imgGDALDS = None
-        if img1Min is None:
-            img1Min = min
-        if img1Max is None:
-            img1Max = max
+        img_gdalds = gdal.Open(input_image1, gdal.GA_ReadOnly)
+        img_gdal_band = img_gdalds.GetRasterBand(img1_band)
+        min, max = img_gdal_band.ComputeRasterMinMax(False)
+        img_gdalds = None
+        if img1_min is None:
+            img1_min = min
+        if img1_max is None:
+            img1_max = max
 
-    if (img2Min is None) or (img2Max is None):
+    if (img2_min is None) or (img2_max is None):
         # Calculate image 2 stats
-        imgGDALDS = gdal.Open(inputImage2, gdal.GA_ReadOnly)
-        imgGDALBand = imgGDALDS.GetRasterBand(img2Band)
-        min, max = imgGDALBand.ComputeRasterMinMax(False)
-        imgGDALDS = None
-        if img2Min is None:
-            img2Min = min
-        if img2Max is None:
-            img2Max = max
+        img_gdalds = gdal.Open(input_image2, gdal.GA_ReadOnly)
+        img_gdal_band = img_gdalds.GetRasterBand(img2_band)
+        min, max = img_gdal_band.ComputeRasterMinMax(False)
+        img_gdalds = None
+        if img2_min is None:
+            img2_min = min
+        if img2_max is None:
+            img2_max = max
 
-    # Images are flipped so axis' come out correctly.
-    outBinSizeImg1, outBinSizeImg2, rSq = imagecalc.get2DImageHistogram(
-        inputImage2,
-        inputImage1,
-        tmpOutFile,
+    # Note. Y axis is flipped.
+    out_bin_size_img1, out_bin_size_img2, rSq = rsgislib.imagecalc.get_2d_img_histogram(
+        input_image2,
+        input_image1,
+        tmp_out_file,
         gdalformat,
-        img2Band,
-        img1Band,
-        numBins,
-        img2Min,
-        img2Max,
-        img1Min,
-        img1Max,
-        img2Scale,
-        img1Scale,
-        img2Off,
-        img1Off,
-        normOutput,
+        img2_band,
+        img1_band,
+        num_bins,
+        img2_min,
+        img2_max,
+        img1_min,
+        img1_max,
+        img2_scale,
+        img1_scale,
+        img2_off,
+        img1_off,
+        norm_output,
     )
-    print("Image1 Bin Size: ", outBinSizeImg1)
-    print("Image2 Bin Size: ", outBinSizeImg2)
+    print("Image1 Bin Size: ", out_bin_size_img1)
+    print("Image2 Bin Size: ", out_bin_size_img2)
     print("rSq: ", rSq)
 
     print("Read Image Data")
-    plotGDALImg = gdal.Open(tmpOutFile, gdal.GA_ReadOnly)
-    plotImgBand = plotGDALImg.GetRasterBand(1)
-    dataArr = plotImgBand.ReadAsArray().astype(float)
-    plotGDALImg = None
+    plot_gdal_img = gdal.Open(tmp_out_file, gdal.GA_ReadOnly)
+    plot_img_band = plot_gdal_img.GetRasterBand(1)
+    data_arr = plot_img_band.ReadAsArray().astype(float)
+    print(data_arr.shape)
+    data_arr = numpy.flipud(data_arr)
+    print(data_arr.shape)
+    plot_gdal_img = None
 
     fig = plt.figure(figsize=(7, 7), dpi=80)
     ax1 = fig.add_subplot(111)
 
-    img1MinSc = img1Off + (img1Min * img1Scale)
-    img1MaxSc = img1Off + (img1Max * img1Scale)
-    img2MinSc = img2Off + (img2Min * img2Scale)
-    img2MaxSc = img2Off + (img2Max * img2Scale)
+    img1_min_sc = img1_off + (img1_min * img1_scale)
+    img1_max_sc = img1_off + (img1_max * img1_scale)
+    img2_min_sc = img2_off + (img2_min * img2_scale)
+    img2_max_sc = img2_off + (img2_max * img2_scale)
 
-    minVal = numpy.min(dataArr[dataArr != 0])
-    maxVal = numpy.max(dataArr)
+    min_val = numpy.min(data_arr[data_arr != 0])
+    max_val = numpy.max(data_arr)
 
-    print("Min Value: ", minVal)
-    print("Max Value: ", maxVal)
+    print("Min Value: ", min_val)
+    print("Max Value: ", max_val)
 
     cmap = plt.get_cmap(ctable)
     mClrs.Colormap.set_under(cmap, color="white")
     mClrs.Colormap.set_over(cmap, color="white")
 
-    imPlot = plt.imshow(
-        dataArr,
+    im_plot = plt.imshow(
+        data_arr,
         cmap=cmap,
         aspect="equal",
         interpolation=interp,
-        norm=mClrs.Normalize(vmin=minVal, vmax=maxVal),
-        vmin=minVal,
-        vmax=maxVal,
-        origin=[0, 0],
-        extent=[img1MinSc, img1MaxSc, img2MinSc, img2MaxSc],
+        norm=mClrs.Normalize(vmin=min_val, vmax=max_val),
+        extent=[img1_min_sc, img1_max_sc, img2_min_sc, img2_max_sc],
     )
     plt.grid(color="k", linestyle="--", linewidth=0.5)
-    rSqStr = ""
+    r_sq_str = ""
     if rSq < 0:
         rSq = 0.00
-    rSqStr = "$r^2 = " + str(round(rSq, 3)) + "$"
-    plt.text(0.05, 0.95, rSqStr, va="center", transform=ax1.transAxes)
-    fig.colorbar(imPlot)
-    plt.title(plotTitle)
-    plt.xlabel(xLabel)
-    plt.ylabel(yLabel)
+    r_sq_str = "$r^2 = " + str(round(rSq, 3)) + "$"
+    plt.text(0.05, 0.95, r_sq_str, va="center", transform=ax1.transAxes)
+    fig.colorbar(im_plot)
+    plt.title(plot_title)
+    plt.xlabel(x_label)
+    plt.ylabel(y_label)
 
-    plt.savefig(outputPlotFile, format="PDF")
+    plt.savefig(output_plot_file)
 
     # Tidy up temporary file.
-    gdalDriver = gdal.GetDriverByName(gdalformat)
-    gdalDriver.Delete(tmpOutFile)
+    gdal_driver = gdal.GetDriverByName(gdalformat)
+    gdal_driver.Delete(tmp_out_file)
 
 
 def plot_image_histogram(
     input_img,
-    imgBand,
-    outputPlotFile,
-    numBins=100,
-    imgMin=None,
-    imgMax=None,
-    normOutput=False,
-    plotTitle="Histogram",
-    xLabel="X Axis",
+    img_band,
+    output_plot_file,
+    num_bins=100,
+    img_min=None,
+    img_max=None,
+    norm_output=False,
+    plot_title="Histogram",
+    x_label="X Axis",
     colour="blue",
     edgecolour="black",
     linewidth=None,
@@ -335,15 +358,25 @@ def plot_image_histogram(
     A function to plot the histogram of an image.
 
     :param input_img: is a string with the path to the image.
-    :param imgBand: is an int specifying the band in the image to be plotted.
-    :param outputPlotFile: is a string specifying the output PDF for the plot.
-    :param numBins: is an int specifying the number of bins within each axis of the histogram (default: 100)
-    :param imgMin: is a double specifying the minimum value to be used in the histogram from the image. If value is None then taken from the image.
-    :param imgMax: is a double specifying the maximum value to be used in the histogram from the image. If value is None then taken from the image.
-    :param normOutput: is a boolean specifying whether the histogram should be normalised (Default: False).
-    :param plotTitle: is a string specifying the title of the plot (Default: '2D Histogram').
-    :param xLabel: is a string specifying the x axis label (Default: 'X Axis')
-    :param colour: is the colour of the bars in the plot (see matplotlib documentation for how to specify, either keyword or RGB values (e.g., [1.0,0,0])
+    :param img_band: is an int specifying the band in the image to be plotted.
+    :param output_plot_file: is a string specifying the output image file for the plot.
+                             Note, the output format is defined using the image
+                             extension. (e.g., img.png would output a PNG image).
+    :param num_bins: is an int specifying the number of bins within each axis of
+                     the histogram (default: 100)
+    :param img_min: is a double specifying the minimum value to be used in the
+                    histogram from the image. If value is None then taken from
+                    the image.
+    :param img_max: is a double specifying the maximum value to be used in the
+                    histogram from the image. If value is None then taken from
+                    the image.
+    :param norm_output: is a boolean specifying whether the histogram should be
+                        normalised (Default: False).
+    :param plot_title: is a string specifying the title of the plot
+                       (Default: '2D Histogram').
+    :param x_label: is a string specifying the x axis label (Default: 'X Axis')
+    :param colour: is the colour of the bars in the plot (see matplotlib documentation
+                   for how to specify, either keyword or RGB values (e.g., [1.0,0,0])
     :param edgecolour: is the colour of the edges of the bars
     :param linewidth: is the thickness of the edges of the bars in the plot.
 
@@ -354,30 +387,30 @@ def plot_image_histogram(
         plotting.plot_image_histogram("Baccini_Manaus_AGB_30.kea", 1, "BacciniHistogram.pdf", numBins=100, imgMin=0, imgMax=400, normOutput=True, plotTitle='Histogram of Baccini Biomass', xLabel='Baccini Biomass', color=[1.0,0.2,1.0], edgecolor='red', linewidth=0)
 
     """
-    if (imgMin is None) or (imgMax is None):
+    if (img_min is None) or (img_max is None):
         # Calculate image 1 stats
         imgGDALDS = gdal.Open(input_img, gdal.GA_ReadOnly)
-        imgGDALBand = imgGDALDS.GetRasterBand(imgBand)
+        imgGDALBand = imgGDALDS.GetRasterBand(img_band)
         min, max = imgGDALBand.ComputeRasterMinMax(False)
         imgGDALDS = None
-        if imgMin is None:
-            imgMin = min
-        if imgMax is None:
-            imgMax = max
+        if img_min is None:
+            img_min = min
+        if img_max is None:
+            img_max = max
 
-    binWidth = (imgMax - imgMin) / numBins
+    binWidth = (img_max - img_min) / num_bins
     print("Bin Size: ", binWidth)
 
-    bins, hMin, hMax = imagecalc.getHistogram(
-        input_img, imgBand, binWidth, False, imgMin, imgMax
+    bins, hMin, hMax = imagecalc.get_histogram(
+        input_img, img_band, binWidth, False, img_min, img_max
     )
 
-    if normOutput:
+    if norm_output:
         sumBins = numpy.sum(bins)
         bins = bins / sumBins
 
-    numBins = len(bins)
-    xLocs = numpy.arange(numBins)
+    num_bins = len(bins)
+    xLocs = numpy.arange(num_bins)
     xLocs = (xLocs * binWidth) - (binWidth / 2)
 
     fig = plt.figure(figsize=(7, 7), dpi=80)
@@ -389,12 +422,12 @@ def plot_image_histogram(
         edgecolor=edgecolour,
         linewidth=linewidth,
     )
-    plt.xlim(imgMin, imgMax)
+    plt.xlim(img_min, img_max)
 
-    plt.title(plotTitle)
-    plt.xlabel(xLabel)
+    plt.title(plot_title)
+    plt.xlabel(x_label)
     plt.ylabel("Freq.")
-    plt.savefig(outputPlotFile, format="PDF")
+    plt.savefig(output_plot_file)
 
 
 def residual_plot(y_true, residuals, out_file, out_format="PNG", title=None):
@@ -830,6 +863,7 @@ def get_gdal_thematic_raster_mpl_imshow(
     out_patches: bool = False,
     cls_names_lut: Dict = None,
     alpha_lyr: bool = False,
+    ctab_alpha: bool = True,
 ) -> Tuple[numpy.array, List[float], list]:
     """
     A function which retrieves thematic image data with a colour table as an
@@ -850,8 +884,10 @@ def get_gdal_thematic_raster_mpl_imshow(
                           key is the pixel value for the class and
     :param alpha_lyr: a boolean specifying whether an alpha channel should be
                       created and therefore the returned array will have 4
-                      rather than 3 dims. If an alpha channel is created then
+                      rather than 3 dims. If an alpha channel is created
                       then background will be transparent.
+    :param ctab_alpha: boolean specifying that the alpha values from the colour
+                       table should be used to display the image (Default: True)
     :return: numpy.array either [n,m,3 or 4], a bbox (xmin, xmax, ymin, ymax)
              specifying the extent of the image data and list of matplotlib patches,
              if out_patches=False then None is returned.
@@ -923,7 +959,7 @@ def get_gdal_thematic_raster_mpl_imshow(
     red_arr = numpy.zeros_like(img_data_arr, dtype=numpy.uint8)
     grn_arr = numpy.zeros_like(img_data_arr, dtype=numpy.uint8)
     blu_arr = numpy.zeros_like(img_data_arr, dtype=numpy.uint8)
-    if alpha_lyr:
+    if alpha_lyr or ctab_alpha:
         alp_arr = numpy.zeros_like(img_data_arr, dtype=numpy.uint8)
 
     lgd_out_patches = None
@@ -935,23 +971,35 @@ def get_gdal_thematic_raster_mpl_imshow(
         red_arr[img_data_arr == i] = clr_tab_entry[0]
         grn_arr[img_data_arr == i] = clr_tab_entry[1]
         blu_arr[img_data_arr == i] = clr_tab_entry[2]
-        if alpha_lyr and (i > 0):
+        if ctab_alpha:
+            alp_arr[img_data_arr == i] = clr_tab_entry[3]
+            if alpha_lyr and (i == 0):
+                alp_arr[img_data_arr == i] = 0
+        elif alpha_lyr and (i > 0):
             alp_arr[img_data_arr == i] = 255
 
         if out_patches and (i > 0):
             cls_name = f"{i}"
             if (cls_names_lut is not None) and (i in cls_names_lut):
                 cls_name = f"{cls_names_lut[i]}"
-            rgb_clr = (
-                clr_tab_entry[0] / 255.0,
-                clr_tab_entry[1] / 255.0,
-                clr_tab_entry[2] / 255.0,
-            )
+            if ctab_alpha:
+                rgb_clr = (
+                    clr_tab_entry[0] / 255.0,
+                    clr_tab_entry[1] / 255.0,
+                    clr_tab_entry[2] / 255.0,
+                    clr_tab_entry[3] / 255.0,
+                )
+            else:
+                rgb_clr = (
+                    clr_tab_entry[0] / 255.0,
+                    clr_tab_entry[1] / 255.0,
+                    clr_tab_entry[2] / 255.0,
+                )
             lgd_out_patches.append(
                 Patch(facecolor=rgb_clr, edgecolor=rgb_clr, label=cls_name)
             )
 
-    if alpha_lyr:
+    if alpha_lyr or ctab_alpha:
         img_clr_data_arr = numpy.stack([red_arr, grn_arr, blu_arr, alp_arr], axis=-1)
     else:
         img_clr_data_arr = numpy.stack([red_arr, grn_arr, blu_arr], axis=-1)
@@ -1418,7 +1466,7 @@ def create_legend_img(
     box_size: Tuple[int] = (10, 20),
     title_str: str = None,
     font_size: int = 12,
-    font: str = "Arial",
+    font: str = None,
     font_clr: Tuple[int] = (0, 0, 0, 255),
     col_width: int = None,
     img_height: int = None,
@@ -1455,6 +1503,7 @@ def create_legend_img(
     :param title_height: Extra height in pixels for the title (Default: 16)
     :param margin: The margin in pixels around the image each and between features
                    (Default: 2)
+    :return: A PIL image object.
 
     """
     import math
@@ -1537,7 +1586,7 @@ def create_legend_img_file(
     box_size: Tuple[int] = (10, 20),
     title_str: str = None,
     font_size: int = 12,
-    font: str = "Arial",
+    font: str = None,
     font_clr: Tuple[int] = (0, 0, 0, 255),
     col_width: int = None,
     img_height: int = None,
@@ -1604,7 +1653,7 @@ def create_legend_img_mpl_ax(
     box_size: Tuple[int] = (10, 20),
     title_str: str = None,
     font_size: int = 12,
-    font: str = "Arial",
+    font: str = None,
     font_clr: Tuple[int] = (0, 0, 0, 255),
     col_width: int = None,
     img_height: int = None,
@@ -1706,7 +1755,9 @@ def create_legend_info_dict(
                       (Default: Alpha)
     :param histogram_col: The name of the histogram column within the RAT
                           (Default: Histogram)
-    :return:
+    :return: dictionary with the classification name as the key and the value a tuple of [Red, Green, Blue, Alpha]
+             values.
+
     """
     import rsgislib.rastergis
 
