@@ -383,6 +383,26 @@ def write_dict_to_json(data_dict: Dict, out_file: str):
         )
 
 
+def dict_to_json_str(data_dict: Dict) -> str:
+    """
+    Write some data to a JSON file. The data would commonly be structured as a dict
+    but could also be a list.
+
+    :param data_dict: The dict (or list) to be written to the output JSON file.
+    :param out_file: The file path to the output file.
+
+    """
+    data_str = json.dumps(
+        data_dict,
+        cls=RSGISNumpyArrayEncoder,
+        sort_keys=True,
+        indent=None,
+        separators=(",", ": "),
+        ensure_ascii=False,
+    )
+    return data_str
+
+
 def write_dict_to_json_gz(data_dict: Dict, out_file: str, encoding: str = "utf-8"):
     """
     Write some data to a JSON file compressed with gzip. The data would commonly be
@@ -864,6 +884,30 @@ def is_summer_winter(lat: float, date: datetime.date) -> int:
     return summer_winter
 
 
+def get_datetime_increment_lst(
+    start_date: datetime.datetime,
+    end_date: datetime.datetime,
+    interval: datetime.timedelta,
+) -> List[datetime.datetime]:
+    """
+    A function which returns a list of datetime objects from the start
+    date in steps of the interval until the date is greater than the
+    end date.
+
+    :param start_date: the start datetime of the sequence
+    :param end_date: the end datetime of the sequence
+    :param interval: the interval as a timedelta object.
+    :return: List of datetime objects
+
+    """
+    date_lst = list()
+    c_date = start_date
+    while c_date < end_date:
+        c_date = c_date + interval
+        date_lst.append(c_date)
+    return date_lst
+
+
 def dict_struct_does_path_exist(dict_struct_obj: Dict, tree_sequence: List) -> bool:
     """
     A function which tests whether a path exists within JSON file.
