@@ -463,7 +463,7 @@ def create_name_col(
     postfix: str = "",
     coords_lat_lon: bool = True,
     int_coords: bool = True,
-    coord_gain: float = 0.0,
+    coord_gain: float = 1.0,
     zero_x_pad: int = 0,
     zero_y_pad: int = 0,
     round_n_digts: int = 0,
@@ -489,7 +489,7 @@ def create_name_col(
     :param coords_lat_lon: A boolean specifying if the coordinates are lat / long
     :param int_coords: A boolean specifying whether to integerise the coordinates.
     :param coord_gain: Apply a gain to the coordinate before integerise.
-                       Default = 0.0 (i.e., no gain)
+                       Default = 1.0 (i.e., no gain)
     :param zero_x_pad: If larger than zero then the X coordinate will be zero padded.
     :param zero_y_pad: If larger than zero then the Y coordinate will be zero padded.
     :param round_n_digts: If larger than zero then the coordinates will be rounded
@@ -649,6 +649,7 @@ def add_numeric_col_lut(
     out_vec_file: str,
     out_vec_lyr: str,
     out_format: str = "GPKG",
+    col_dtype: str = "int",
 ):
     """
     A function which adds a numeric column based off an existing column in the
@@ -663,18 +664,26 @@ def add_numeric_col_lut(
     :param out_vec_file: Output vector file
     :param out_vec_lyr: output vector layer name.
     :param out_format: output file format (default GPKG).
+    :param col_dtype: output data type (default int). Must be either "int" or "float".
 
     """
     import geopandas
 
     import rsgislib.vectorutils
 
+    if col_dtype.lower() not in ["int", "float"]:
+        raise ValueError("col_type must be int or float")
+
     out_format = rsgislib.vectorutils.check_format_name(out_format)
 
     # Open vector file
     base_gpdf = geopandas.read_file(vec_file, layer=vec_lyr)
     # Add output column
-    base_gpdf[out_col] = numpy.zeros((base_gpdf.shape[0]), dtype=int)
+    if col_dtype.lower() == "int":
+        base_gpdf[out_col] = numpy.zeros((base_gpdf.shape[0]), dtype=int)
+    elif col_dtype.lower() == "float":
+        base_gpdf[out_col] = numpy.zeros((base_gpdf.shape[0]), dtype=float)
+
     # Loop values in LUT
     for lut_key in val_lut:
         sel_rows = base_gpdf[ref_col] == lut_key
@@ -1310,7 +1319,7 @@ def drop_vec_cols(
     """
     A function which allows vector columns to be removed from the layer.
 
-    param vec_file: Input vector file
+    :param vec_file: Input vector file
     :param vec_lyr: Input vector layer
     :param drop_cols: List of columns to remove from layer
     :param out_vec_file: the output vector file
@@ -2014,3 +2023,89 @@ def calc_vec_pt_dist_angle(
         data_gdf.to_file(out_vec_file, layer=out_vec_lyr, driver=out_format)
     else:
         data_gdf.to_file(out_vec_file, driver=out_format)
+
+
+def calc_near_dist_to_feats(
+    vec_file: str,
+    vec_lyr: str,
+    vec_dist_file: str,
+    vec_dist_lyr: str,
+    out_vec_file: str,
+    out_vec_lyr: str,
+    out_col: str = "dist",
+    out_format: str = "GPKG",
+):
+    import geopandas
+
+    data_gdf = geopandas.read_file(vec_file, layer=vec_lyr)
+    dist_gdf = geopandas.read_file(vec_dist_file, layer=vec_dist_lyr)
+
+    data_cols = list(data_gdf.columns.values)
+    dist_cols = list(dist_gdf.columns.values)
+
+    data_dist_gdf = geopandas.sjoin_nearest(
+        data_gdf,
+        dist_gdf,
+        distance_col=out_col,
+        lsuffix="left",
+        rsuffix="right",
+        exclusive=True,
+    )
+
+    if out_format == "GPKG":
+        if out_vec_lyr is None:
+            import rsgislib.tools.filetools
+
+            out_vec_lyr = rsgislib.tools.filetools.get_file_basename(
+                out_vec_file, check_valid=True
+            )
+        data_dist_gdf.to_file(out_vec_file, layer=out_vec_lyr, driver=out_format)
+    else:
+        data_dist_gdf.to_file(out_vec_file, driver=out_format)
+
+
+def add_ran_vals_cols(
+    vec_file: str,
+    vec_lyr: str,
+    out_vec_file: str,
+    out_vec_lyr: str,
+    out_format: str = "GPKG",
+    out_col: str = "ran_vals",
+    rnd_seed: int = None,
+):
+    """
+    A function which adds a new column with a random (integer) value assigned
+    to each row. Note, this does not guarantee that the random values will be
+    unique for each row.
+
+    :param vec_file: Input vector file.
+    :param vec_lyr: Input vector layer within the input file.
+    :param out_vec_file: Output vector file
+    :param out_vec_lyr: Output vector layer name.
+    :param out_format: output file format (default GPKG).
+    :param out_col: The output numeric column with the random value
+    :param rnd_seed: the random seed for the random number generator.
+                     Default is None.
+
+    """
+    import geopandas
+    import os
+
+    if out_vec_lyr is None:
+        out_vec_lyr = os.path.splitext(os.path.basename(out_vec_file))[0]
+
+    data_gdf = geopandas.read_file(vec_file, layer=vec_lyr)
+
+    rng = numpy.random.default_rng(seed=rnd_seed)
+
+    n_rows = len(data_gdf)
+    data_gdf[out_col] = rng.integers(low=1, high=n_rows * 10, size=n_rows)
+
+    if out_format == "GPKG":
+        if out_vec_lyr is None:
+            raise rsgislib.RSGISPyException(
+                "If output format is GPKG then an output layer is required."
+            )
+        data_gdf.to_file(out_vec_file, layer=out_vec_lyr, driver=out_format)
+    else:
+        data_gdf.to_file(out_vec_file, driver=out_format)
