@@ -25,7 +25,7 @@
 
 namespace rsgis{namespace calib{
     
-    RSGISLandsatFMaskPass1CloudMasking::RSGISLandsatFMaskPass1CloudMasking(unsigned int scaleFactor, unsigned int numLSBands, double whitenessThreshold) throw(rsgis::img::RSGISImageCalcException):rsgis::img::RSGISCalcImageValue(16)
+    RSGISLandsatFMaskPass1CloudMasking::RSGISLandsatFMaskPass1CloudMasking(unsigned int scaleFactor, unsigned int numLSBands, double whitenessThreshold) :rsgis::img::RSGISCalcImageValue(16)
     {
         this->scaleFactor = scaleFactor;
         this->whitenessThreshold = whitenessThreshold;
@@ -108,7 +108,7 @@ namespace rsgis{namespace calib{
         }
     }
     
-    void RSGISLandsatFMaskPass1CloudMasking::calcImageValue(float *bandValues, int numBands, double *output) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISLandsatFMaskPass1CloudMasking::calcImageValue(float *bandValues, int numBands, double *output) 
     {
         bool noData = true;
         for(unsigned i = 0; i < numBands; ++i)
@@ -303,13 +303,13 @@ namespace rsgis{namespace calib{
     }
     
     
-    RSGISLandsatFMaskExportPass1LandWaterCloudMasking::RSGISLandsatFMaskExportPass1LandWaterCloudMasking()throw(rsgis::img::RSGISImageCalcException):rsgis::img::RSGISCalcImageValue(1)
+    RSGISLandsatFMaskExportPass1LandWaterCloudMasking::RSGISLandsatFMaskExportPass1LandWaterCloudMasking():rsgis::img::RSGISCalcImageValue(1)
     {
         this->numValidPxls = 0.0;
         this->numPCPPxls = 0.0;
     }
     
-    void RSGISLandsatFMaskExportPass1LandWaterCloudMasking::calcImageValue(float *bandValues, int numBands, double *output) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISLandsatFMaskExportPass1LandWaterCloudMasking::calcImageValue(float *bandValues, int numBands, double *output) 
     {
         output[0] = 0;
         if(bandValues[10] == 1)
@@ -350,7 +350,7 @@ namespace rsgis{namespace calib{
     
     
     
-    RSGISLandsatFMaskPass2ClearSkyCloudProbCloudMasking::RSGISLandsatFMaskPass2ClearSkyCloudProbCloudMasking(unsigned int scaleFactor, unsigned int numLSBands, double water82ndThres, double land82ndThres, double land17thThres) throw(rsgis::img::RSGISImageCalcException):rsgis::img::RSGISCalcImageValue(6)
+    RSGISLandsatFMaskPass2ClearSkyCloudProbCloudMasking::RSGISLandsatFMaskPass2ClearSkyCloudProbCloudMasking(unsigned int scaleFactor, unsigned int numLSBands, double water82ndThres, double land82ndThres, double land17thThres) :rsgis::img::RSGISCalcImageValue(6)
     {
         this->scaleFactor = scaleFactor;
         this->numLSBands = numLSBands;
@@ -418,7 +418,7 @@ namespace rsgis{namespace calib{
         }
     }
     
-    void RSGISLandsatFMaskPass2ClearSkyCloudProbCloudMasking::calcImageValue(float *bandValues, int numBands, double *output) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISLandsatFMaskPass2ClearSkyCloudProbCloudMasking::calcImageValue(float *bandValues, int numBands, double *output) 
     {
         bool noData = true;
         for(unsigned i = 1; i < numBands; ++i)
@@ -508,7 +508,7 @@ namespace rsgis{namespace calib{
     }
     
     
-    RSGISLandsatFMaskPass2CloudMasking::RSGISLandsatFMaskPass2CloudMasking(unsigned int scaleFactor, unsigned int numLSBands, double landCloudProbUpperThres, double waterCloudProbUpperThres, double lowerLandTempThres) throw(rsgis::img::RSGISImageCalcException):rsgis::img::RSGISCalcImageValue(1)
+    RSGISLandsatFMaskPass2CloudMasking::RSGISLandsatFMaskPass2CloudMasking(unsigned int scaleFactor, unsigned int numLSBands, double landCloudProbUpperThres, double waterCloudProbUpperThres, double lowerLandTempThres) :rsgis::img::RSGISCalcImageValue(1)
     {
         this->scaleFactor = scaleFactor;
         this->numLSBands = numLSBands;
@@ -588,7 +588,7 @@ namespace rsgis{namespace calib{
         }
     }
     
-    void RSGISLandsatFMaskPass2CloudMasking::calcImageValue(float *bandValues, int numBands, double *output) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISLandsatFMaskPass2CloudMasking::calcImageValue(float *bandValues, int numBands, double *output) 
     {
         bool noData = true;
         for(unsigned i = 1; i <= numLSBands; ++i)
@@ -675,7 +675,7 @@ namespace rsgis{namespace calib{
     
     
 
-    void RSGISCalcImageCloudMajorityFilter::calcImageValue(float ***dataBlock, int numBands, int winSize, double *output) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISCalcImageCloudMajorityFilter::calcImageValue(float ***dataBlock, int numBands, int winSize, double *output) 
     {
         if(numBands != 1)
         {
@@ -711,7 +711,7 @@ namespace rsgis{namespace calib{
     }
     
   
-    void RSGISCalcImagePotentialCloudShadowsMask::calcImageValue(float *bandValues, int numBands, double *output) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISCalcImagePotentialCloudShadowsMask::calcImageValue(float *bandValues, int numBands, double *output) 
     {
         if(numBands != 5)
         {
@@ -745,7 +745,7 @@ namespace rsgis{namespace calib{
     
     
     
-    void RSGISCalcImagePotentialCloudShadowsMaskSingleInput::calcImageValue(float *bandValues, int numBands, double *output) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISCalcImagePotentialCloudShadowsMaskSingleInput::calcImageValue(float *bandValues, int numBands, double *output) 
     {
         if(numBands != 3)
         {
@@ -777,7 +777,7 @@ namespace rsgis{namespace calib{
     
     
     
-    void RSGISCalcCloudParams::calcCloudHeights(GDALDataset *thermal, GDALDataset *cloudClumpsDS, GDALDataset *initCloudHeights, double lowerLandThres, double upperLandThres, float scaleFactor)throw(rsgis::img::RSGISImageCalcException)
+    void RSGISCalcCloudParams::calcCloudHeights(GDALDataset *thermal, GDALDataset *cloudClumpsDS, GDALDataset *initCloudHeights, double lowerLandThres, double upperLandThres, float scaleFactor)
     {
         try
         {
@@ -824,7 +824,7 @@ namespace rsgis{namespace calib{
             double *hBaseMin = new double[numcloudsRATHistoRows];
             double *hBaseMax = new double[numcloudsRATHistoRows];
             
-            geos::geom::Envelope *env = new geos::geom::Envelope();
+            OGREnvelope *env = new OGREnvelope();
             
             rsgis::img::RSGISImagePercentiles calcImgPercentiles;
             
@@ -838,8 +838,11 @@ namespace rsgis{namespace calib{
                 if(r > 8)
                 {
                     percentile = ((r-8.0)*(r-8.0)) / (r*r);
-                    env->init(minX[i], maxX[i], minY[i], maxY[i]);
-                    
+                    env->MinX = minX[i];
+                    env->MaxX = maxX[i];
+                    env->MinY = minY[i];
+                    env->MaxY = maxY[i];
+
                     cloudBase[i] = calcImgPercentiles.getPercentile(thermal, 1, cloudClumpsDS, i, percentile, 0, true, env, true);
                 }
                 else
@@ -861,7 +864,6 @@ namespace rsgis{namespace calib{
                 {
                     hBaseMax[i] = 12;
                 }
-                
             }
             
             cloudBase[0] = 0;
@@ -906,7 +908,7 @@ namespace rsgis{namespace calib{
         
     }
     
-    void RSGISCalcCloudParams::calcCloudHeightsNoThermal(GDALDataset *cloudClumpsDS, GDALDataset *initCloudHeightsDS)throw(rsgis::img::RSGISImageCalcException)
+    void RSGISCalcCloudParams::calcCloudHeightsNoThermal(GDALDataset *cloudClumpsDS, GDALDataset *initCloudHeightsDS)
     {
         try
         {
@@ -959,7 +961,7 @@ namespace rsgis{namespace calib{
     }
     
     
-    void RSGISCalcCloudParams::projFitCloudShadow(GDALDataset *cloudClumpsDS, GDALDataset *initCloudHeights, GDALDataset *potentCloudShadowRegions, GDALDataset *cloudShadowTestRegionsDS, GDALDataset *cloudShadowRegionsDS, double sunAz, double sunZen, double senAz, double senZen)throw(rsgis::img::RSGISImageCalcException)
+    void RSGISCalcCloudParams::projFitCloudShadow(GDALDataset *cloudClumpsDS, GDALDataset *initCloudHeights, GDALDataset *potentCloudShadowRegions, GDALDataset *cloudShadowTestRegionsDS, GDALDataset *cloudShadowRegionsDS, double sunAz, double sunZen, double senAz, double senZen)
     {
         try
         {
@@ -979,7 +981,7 @@ namespace rsgis{namespace calib{
             RSGISEditCloudShadowImg editFinalShadImg = RSGISEditCloudShadowImg(cloudShadowRegionsDS, 1);
             editFinalShadImg.reset();
             rsgis::img::RSGISExtractPxlsAsPts getPxPts;
-            geos::geom::Envelope *env = new geos::geom::Envelope();
+            OGREnvelope *env = new OGREnvelope();
             double baseHeight = 0.0;
             double pxlX = 0.0;
             double pxlY = 0.0;
@@ -998,21 +1000,18 @@ namespace rsgis{namespace calib{
             double *bestFitBaseLine = new double[numClumps];
             bestFitBaseLine[0] = 0.0;
             
-            int feedback = numClumps/10.0;
-            int feedbackCounter = 0;
             std::cout << "Iteratively finding optimal cloud height. This step may take a while; there are " << numClumps << " clumps\n";
-            std::cout << "Started ." << std::flush;
+            rsgis_tqdm pbar;
             for(size_t i = 1; i < numClumps; ++i)
             {
-                if((feedback != 0) && ((i % feedback) == 0))
-                {
-                    std::cout << "." << feedbackCounter << "." << std::flush;
-                    feedbackCounter = feedbackCounter + 10;
-                }
+                pbar.progress(i, numClumps);
                 
                 std::vector<std::pair<std::pair<double,double>,double> > *pxPts = new std::vector<std::pair<std::pair<double,double>,double> >();
                 pxPts->reserve(cloudsRATHisto[i]);
-                env->init(minX[i], maxX[i], minY[i], maxY[i]);
+                env->MinX = minX[i];
+                env->MaxX = maxX[i];
+                env->MinY = minY[i];
+                env->MaxY = maxY[i];
                 getPxPts.exportPixelsAsPointsWithVal(cloudClumpsDS, (float)i, initCloudHeights, 2, pxPts, true, env);
                 
                 
@@ -1070,7 +1069,7 @@ namespace rsgis{namespace calib{
                 
                 delete pxPts;
             }
-            std::cout << ". Complete.\n";
+            pbar.finish();
             attUtils.writeRealColumn(cloudsRAT, "FitBaseLine", bestFitBaseLine, numClumps);
             rsgis::math::RSGISMathsUtils mathUtils;
             
@@ -1109,21 +1108,19 @@ namespace rsgis{namespace calib{
             }
             attUtils.writeRealColumn(cloudsRAT, "FitBaseLineEdit", bestFitBaseLine, numClumps);
             
-            feedbackCounter = 0;
+            pbar.reset();
             std::cout << "Producing cloud shadow mask using optimal heights:\n";
-            std::cout << "Started ." << std::flush;
             // Add Shadow with most correspondance to Final Shadow Image.
             for(size_t i = 1; i < numClumps; ++i)
             {
-                if((feedback != 0) && ((i % feedback) == 0))
-                {
-                    std::cout << "." << feedbackCounter << "." << std::flush;
-                    feedbackCounter = feedbackCounter + 10;
-                }
+                pbar.progress(i, numClumps);
                 
                 std::vector<std::pair<std::pair<double,double>,double> > *pxPts = new std::vector<std::pair<std::pair<double,double>,double> >();
                 pxPts->reserve(cloudsRATHisto[i]);
-                env->init(minX[i], maxX[i], minY[i], maxY[i]);
+                env->MinX = minX[i];
+                env->MaxX = maxX[i];
+                env->MinY = minY[i];
+                env->MaxY = maxY[i];
                 getPxPts.exportPixelsAsPointsWithVal(cloudClumpsDS, (float)i, initCloudHeights, 2, pxPts, true, env);
                 
                 for(std::vector<std::pair<std::pair<double,double>,double> >::iterator iterPts = pxPts->begin(); iterPts != pxPts->end(); ++iterPts)
@@ -1144,7 +1141,7 @@ namespace rsgis{namespace calib{
                 
                 delete pxPts;
             }
-            std::cout << ". Complete.\n";
+            pbar.finish();
             
             delete env;
             delete[] cloudBase;
@@ -1194,14 +1191,18 @@ namespace rsgis{namespace calib{
         this->brX = this->tlX + (this->nXPxl * this->xRes);
         this->brY = this->tlY - (this->nYPxl * this->yRes);
         
-        extent.init(0,0,0,0);
+        extent.MinX = 0;
+        extent.MaxX = 0;
+        extent.MinY = 0;
+        extent.MaxY = 0;
+
         this->firstPts = true;
         
         this->calcCloudShadCorr = new RSGISCalcCloudShadowCorrespondance();
         this->imgCalc = new rsgis::img::RSGISCalcImage(this->calcCloudShadCorr);
     }
     
-    bool RSGISEditCloudShadowImg::turnOnPxl(double x, double y)throw(rsgis::img::RSGISImageCalcException)
+    bool RSGISEditCloudShadowImg::turnOnPxl(double x, double y)
     {
         bool rtnStat = true;
         if((x < this->tlX) | (x > this->brX))
@@ -1227,12 +1228,15 @@ namespace rsgis{namespace calib{
                 this->testImgBand->RasterIO(GF_Write, xPxlLoc, yPxlLoc, 1, 1, &outValue, 1, 1, GDT_Float32, 0, 0);
                 if(this->firstPts)
                 {
-                    extent.init(x,x,y,y);
+                    extent.MinX = x;
+                    extent.MaxX = x;
+                    extent.MinY = y;
+                    extent.MaxY = y;
                     this->firstPts=false;
                 }
                 else
                 {
-                    extent.expandToInclude(x, y);
+                    extent.Merge(x, y);
                 }
             }
             else
@@ -1245,40 +1249,43 @@ namespace rsgis{namespace calib{
         return rtnStat;
     }
     
-    void RSGISEditCloudShadowImg::reset()throw(rsgis::img::RSGISImageCalcException)
+    void RSGISEditCloudShadowImg::reset()
     {
         this->testImgBand->Fill(0.0);
-        extent.init(0,0,0,0);
+        extent.MinX = 0;
+        extent.MaxX = 0;
+        extent.MinY = 0;
+        extent.MaxY = 0;
         this->firstPts = true;
     }
     
-    bool RSGISEditCloudShadowImg::calcCorrelation(GDALDataset *cloudClumpsDS, GDALDataset *potentCloudShadowRegions, GDALDataset *cloudShadowTestRegionsDS, double *cloudPropOverlap, unsigned long *numPxlOverlap)throw(rsgis::img::RSGISImageCalcException)
+    bool RSGISEditCloudShadowImg::calcCorrelation(GDALDataset *cloudClumpsDS, GDALDataset *potentCloudShadowRegions, GDALDataset *cloudShadowTestRegionsDS, double *cloudPropOverlap, unsigned long *numPxlOverlap)
     {
         bool insideimg = true;
         try
         {
             // Check envelope is within image (i.e., shadow hasn't been projected outside of the image extent)
-            if((extent.getMinX() < this->tlX) | (extent.getMinX() > this->brX))
+            if((extent.MinX < this->tlX) | (extent.MinX > this->brX))
             {
                 insideimg = false;
             }
-            else if((extent.getMaxX() < this->tlX) | (extent.getMaxX() > this->brX))
+            else if((extent.MaxX < this->tlX) | (extent.MaxX > this->brX))
             {
                 insideimg = false;
             }
-            else if((extent.getMinY() < this->brY) | (extent.getMinY() > this->tlY))
+            else if((extent.MinY < this->brY) | (extent.MinY > this->tlY))
             {
                 insideimg = false;
             }
-            else if((extent.getMaxY() < this->brY) | (extent.getMaxY() > this->tlY))
+            else if((extent.MaxY < this->brY) | (extent.MaxY > this->tlY))
             {
                 insideimg = false;
             }
-            else if(extent.getWidth() < (this->xRes*2))
+            else if((extent.MaxX - extent.MinX) < (this->xRes*2))
             {
                 insideimg = false;
             }
-            else if(extent.getHeight() < (this->yRes*2))
+            else if((extent.MaxY - extent.MinY) < (this->yRes*2))
             {
                 insideimg = false;
             }
@@ -1339,7 +1346,7 @@ namespace rsgis{namespace calib{
     
     
     
-    void RSGISCalcPxlCloudBaseAndTopHeight::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals, double *output) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISCalcPxlCloudBaseAndTopHeight::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals, double *output) 
     {
         if(numIntVals != 1)
         {
@@ -1388,7 +1395,7 @@ namespace rsgis{namespace calib{
     }
     
     
-    void RSGISCalcPxlCloudBaseAndTopHeightNoThermal::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals, double *output) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISCalcPxlCloudBaseAndTopHeightNoThermal::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals, double *output) 
     {
         if(numIntVals != 1)
         {
@@ -1415,7 +1422,7 @@ namespace rsgis{namespace calib{
     }
     
     
-    void RSGISCalcCloudShadowCorrespondance::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISCalcCloudShadowCorrespondance::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) 
     {
         if(numIntVals != 3)
         {
@@ -1454,7 +1461,7 @@ namespace rsgis{namespace calib{
     }
     
     
-    void RSGISCalcCombineMasks::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals, double *output) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISCalcCombineMasks::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals, double *output) 
     {
         if(numIntVals != 2)
         {
@@ -1477,7 +1484,7 @@ namespace rsgis{namespace calib{
     }
     
     
-    void RSGISExportMaskForOverPCPThreshold::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals, double *output) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISExportMaskForOverPCPThreshold::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals, double *output) 
     {
         if(numIntVals != 1)
         {
