@@ -38,12 +38,10 @@
 #include "segmentation/RSGISGenMeanSegImage.h"
 #include "segmentation/RSGISRandomColourClumps.h"
 #include "segmentation/RSGISMergeSegmentationTiles.h"
-#include "segmentation/RSGISBottomUpShapeFeatureExtraction.h"
 #include "segmentation/RSGISMergeSegmentations.h"
 #include "segmentation/RSGISMergeSegments.h"
 #include "segmentation/RSGISCreateImageGrid.h"
 #include "segmentation/RSGISDropClumps.h"
-#include "segmentation/RSGISRegionGrowSegmentsPixels.h"
 
 #include "rastergis/RSGISRasterAttUtils.h"
 #include "rastergis/RSGISCalcImageStatsAndPyramids.h"
@@ -52,7 +50,7 @@
 
 namespace rsgis{ namespace cmds {
     
-    void executeLabelPixelsFromClusterCentres(std::string inputImage, std::string outputImage, std::string clusterCentresFile, bool ignoreZeros, std::string imageFormat)throw(RSGISCmdException)
+    void executeLabelPixelsFromClusterCentres(std::string inputImage, std::string outputImage, std::string clusterCentresFile, bool ignoreZeros, std::string imageFormat)
     {
         try
         {
@@ -81,7 +79,7 @@ namespace rsgis{ namespace cmds {
         }
     }
     
-    void executeEliminateSinglePixels(std::string inputImage, std::string clumpsImage, std::string outputImage, std::string tempImage, std::string imageFormat, bool processInMemory, bool ignoreZeros)throw(RSGISCmdException)
+    void executeEliminateSinglePixels(std::string inputImage, std::string clumpsImage, std::string outputImage, std::string tempImage, std::string imageFormat, bool processInMemory, bool ignoreZeros)
     {
         try
         {
@@ -136,7 +134,7 @@ namespace rsgis{ namespace cmds {
         }
     }
     
-    void executeClump(std::string inputImage, std::string outputImage, std::string imageFormat, bool processInMemory, bool noDataValProvided, float noDataVal, bool addRatPxlVals) throw(RSGISCmdException)
+    void executeClump(std::string inputImage, std::string outputImage, std::string imageFormat, bool processInMemory, bool noDataValProvided, float noDataVal, bool addRatPxlVals) 
     {        
         try
         {
@@ -239,7 +237,7 @@ namespace rsgis{ namespace cmds {
         }
     }
     
-    void executeRMSmallClumpsStepwise(std::string inputImage, std::string clumpsImage, std::string outputImage, std::string imageFormat, bool stretchStatsAvail, std::string stretchStatsFile, bool storeMean, bool processInMemory, unsigned int minClumpSize, float specThreshold)throw(RSGISCmdException)
+    void executeRMSmallClumpsStepwise(std::string inputImage, std::string clumpsImage, std::string outputImage, std::string imageFormat, bool stretchStatsAvail, std::string stretchStatsFile, bool storeMean, bool processInMemory, unsigned int minClumpSize, float specThreshold)
     {
         try
         {
@@ -332,7 +330,7 @@ namespace rsgis{ namespace cmds {
         }
     }
     
-    void executeRelabelClumps(std::string inputImage, std::string outputImage, std::string imageFormat, bool processInMemory) throw(RSGISCmdException)
+    void executeRelabelClumps(std::string inputImage, std::string outputImage, std::string imageFormat, bool processInMemory) 
     {
         try
         {
@@ -394,7 +392,7 @@ namespace rsgis{ namespace cmds {
         }
     }
     
-    void executeMeanImage(std::string inputImage, std::string clumpsImage, std::string outputImage, std::string imageFormat, RSGISLibDataType outDataType, bool processInMemory) throw(RSGISCmdException)
+    void executeMeanImage(std::string inputImage, std::string clumpsImage, std::string outputImage, std::string imageFormat, RSGISLibDataType outDataType, bool processInMemory) 
     {
         try
         {
@@ -465,7 +463,7 @@ namespace rsgis{ namespace cmds {
         }
     }
 
-    void executeRandomColourClumps(std::string inputImage, std::string outputImage, std::string imageFormat, bool processInMemory, std::string importLUTFile, bool importLUT, std::string exportLUTFile, bool exportLUT)throw(RSGISCmdException)
+    void executeRandomColourClumps(std::string inputImage, std::string outputImage, std::string imageFormat, bool processInMemory, std::string importLUTFile, bool importLUT, std::string exportLUTFile, bool exportLUT)
     {
         try
         {
@@ -523,7 +521,7 @@ namespace rsgis{ namespace cmds {
         }
     }
     
-    void executeUnionOfClumps(std::vector<std::string> inputImagePaths, std::string outputImage, std::string imageFormat, bool noDataValProvided, float noDataVal, bool addRatPxlVals)throw(RSGISCmdException)
+    void executeUnionOfClumps(std::vector<std::string> inputImagePaths, std::string outputImage, std::string imageFormat, bool noDataValProvided, float noDataVal, bool addRatPxlVals)
     {
         try
         {
@@ -561,7 +559,7 @@ namespace rsgis{ namespace cmds {
         }
     }
     
-    void executeMergeSegmentationTiles(std::string outputImage, std::string borderMaskImage, std::vector<std::string> inputImagePaths, unsigned int tileBoundary, unsigned int tileOverlap, unsigned int tileBody, std::string colsName)throw(RSGISCmdException)
+    void executeMergeSegmentationTiles(std::string outputImage, std::string borderMaskImage, std::vector<std::string> inputImagePaths, unsigned int tileBoundary, unsigned int tileOverlap, unsigned int tileBody, std::string colsName)
     {
         try
         {
@@ -601,7 +599,7 @@ namespace rsgis{ namespace cmds {
         }
     }
     
-    void executeFindTileBordersMask(std::vector<std::string> inputImagePaths, std::string borderMaskImage, unsigned int tileBoundary, unsigned int tileOverlap, unsigned int tileBody, std::string colsName)throw(RSGISCmdException)
+    void executeFindTileBordersMask(std::vector<std::string> inputImagePaths, std::string borderMaskImage, unsigned int tileBoundary, unsigned int tileOverlap, unsigned int tileBody, std::string colsName)
     {
         try
         {
@@ -632,7 +630,7 @@ namespace rsgis{ namespace cmds {
         }
     }
     
-    void executeMergeClumpImages(std::vector<std::string> inputImagePaths, std::string outputImage, bool mergeRATs)throw(RSGISCmdException)
+    void executeMergeClumpImages(std::vector<std::string> inputImagePaths, std::string outputImage, bool mergeRATs)
     {
         try
         {
@@ -663,69 +661,7 @@ namespace rsgis{ namespace cmds {
         }
     }
     
-    void executeExtractBrightFeatures(std::string inputImage, std::string maskImage, std::string outputImage, std::string temp1Image, std::string temp2Image, std::string outputFormat, float initThres, float thresIncrement, float thresholdUpper, std::vector<rsgis::cmds::FeatureShapeDescription*> shapeFeatDescript)throw(RSGISCmdException)
-    {
-        /*
-        try
-        {
-            rsgis::img::RSGISImageUtils imgUtils;
-            GDALAllRegister();
-            
-            GDALDataset *inputDataset = (GDALDataset *) GDALOpen(inputImage.c_str(), GA_Update);
-            if(inputDataset == NULL)
-            {
-                std::string message = std::string("Could not open image ") + inputImage;
-                throw rsgis::RSGISImageException(message.c_str());
-            }
-            
-            GDALDataset *maskDataset = (GDALDataset *) GDALOpen(maskImage.c_str(), GA_Update);
-            if(inputDataset == NULL)
-            {
-                std::string message = std::string("Could not open image ") + maskImage;
-                throw rsgis::RSGISImageException(message.c_str());
-            }
-            
-            GDALDataset *outputDataset = imgUtils.createCopy(inputDataset, 1, outputImage, outputFormat, GDT_Int32);
-            
-            GDALDataset *temp1Dataset = imgUtils.createCopy(inputDataset, 1, temp1Image, outputFormat, GDT_Int32);
-            GDALDataset *temp2Dataset = imgUtils.createCopy(inputDataset, 1, temp2Image, outputFormat, GDT_Int32);
-            
-            std::vector<rsgis::segment::FeatureShapeDescription*> shapeFeatDescriptSegs;
-            shapeFeatDescriptSegs.reserve(shapeFeatDescript.size());
-            rsgis::segment::FeatureShapeDescription *feat = NULL;
-            for(std::vector<rsgis::cmds::FeatureShapeDescription*>::iterator iterFeats = shapeFeatDescript.begin(); iterFeats != shapeFeatDescript.end(); ++iterFeats)
-            {
-                feat = new rsgis::segment::FeatureShapeDescription();
-                feat->area = (*iterFeats)->area;
-                feat->areaLower = (*iterFeats)->areaLower;
-                feat->areaUpper = (*iterFeats)->areaUpper;
-                feat->lenWidth = (*iterFeats)->lenWidth;
-                feat->lenWidthLower = (*iterFeats)->lenWidthLower;
-                feat->lenWidthUpper = (*iterFeats)->lenWidthUpper;
-                shapeFeatDescriptSegs.push_back(feat);
-            }
-            
-            rsgis::segment::RSGISBottomUpShapeFeatureExtraction rsgisExtractFeats;
-            rsgisExtractFeats.extractBrightFeatures(inputDataset, maskDataset, outputDataset, temp1Dataset, temp2Dataset, initThres, thresIncrement, thresholdUpper, shapeFeatDescriptSegs);
-            
-            GDALClose(inputDataset);
-            GDALClose(outputDataset);
-            GDALClose(temp1Dataset);
-            GDALClose(temp2Dataset);
-            GDALClose(maskDataset);
-        }
-        catch (rsgis::RSGISException &e)
-        {
-            throw rsgis::cmds::RSGISCmdException(e.what());
-        }
-        catch (std::exception &e)
-        {
-            throw rsgis::cmds::RSGISCmdException(e.what());
-        }
-         */
-    }
-    
-    void executeRMSmallClumps(std::string clumpsImage, std::string outputImage, float threshold, std::string imgFormat)throw(RSGISCmdException)
+    void executeRMSmallClumps(std::string clumpsImage, std::string outputImage, float threshold, std::string imgFormat)
     {
         GDALAllRegister();
         GDALDataset *clumpsDataset;
@@ -772,7 +708,7 @@ namespace rsgis{ namespace cmds {
     }
             
             
-    void executeGenerateRegularGrid(std::string inputImage, std::string outputClumpImage, std::string imageFormat, unsigned int numXPxls, unsigned int numYPxls, bool offset)throw(RSGISCmdException)
+    void executeGenerateRegularGrid(std::string inputImage, std::string outputClumpImage, std::string imageFormat, unsigned int numXPxls, unsigned int numYPxls, bool offset)
     {
         GDALAllRegister();
         
@@ -811,7 +747,7 @@ namespace rsgis{ namespace cmds {
     }
             
             
-    void executeIncludeClumpedRegion(std::string inputClumps, std::string inputRegion, std::string outputClumpImage, std::string imageFormat)throw(RSGISCmdException)
+    void executeIncludeClumpedRegion(std::string inputClumps, std::string inputRegion, std::string outputClumpImage, std::string imageFormat)
     {
         GDALAllRegister();
         
@@ -869,7 +805,7 @@ namespace rsgis{ namespace cmds {
         }
     }
             
-    void executeMergeSelectClumps2Neighbour(std::string inputImage, std::string clumpsImage, std::string outputImage, std::string imageFormat, std::string selectClumpsCol, std::string noDataClumpsCol)throw(RSGISCmdException)
+    void executeMergeSelectClumps2Neighbour(std::string inputImage, std::string clumpsImage, std::string outputImage, std::string imageFormat, std::string selectClumpsCol, std::string noDataClumpsCol)
     {
         try
         {
@@ -931,7 +867,7 @@ namespace rsgis{ namespace cmds {
     }
             
             
-    void executeDropSelectedClumps(std::string clumpsImage, std::string outputImage, std::string imageFormat, std::string selectClumpsCol)throw(RSGISCmdException)
+    void executeDropSelectedClumps(std::string clumpsImage, std::string outputImage, std::string imageFormat, std::string selectClumpsCol)
     {
         try
         {
@@ -959,7 +895,7 @@ namespace rsgis{ namespace cmds {
         }
     }
             
-    void executeMergeClumpsEquivalentVal(std::string clumpsImage, std::string outputImage, std::string imageFormat, std::vector<std::string> clumpsValCols)throw(RSGISCmdException)
+    void executeMergeClumpsEquivalentVal(std::string clumpsImage, std::string outputImage, std::string imageFormat, std::vector<std::string> clumpsValCols)
     {
         try
         {
@@ -1011,54 +947,7 @@ namespace rsgis{ namespace cmds {
             throw rsgis::cmds::RSGISCmdException(e.what());
         }
     }
-            
-            
-    DllExport void executePxlGrowRegions(std::string clumpsImage, std::string valsImage, std::string outputImage, std::string imageFormat, std::string muParseCriteria, std::vector<VarImgBandPairs> varNameBandPairs)throw(RSGISCmdException)
-    {
-        try
-        {
-            rsgis::img::RSGISImageUtils imgUtils;
-            GDALAllRegister();
-            GDALDataset *clumpDS = (GDALDataset *) GDALOpen(clumpsImage.c_str(), GA_ReadOnly);
-            if(clumpDS == NULL)
-            {
-                std::string message = std::string("Could not open image ") + clumpsImage;
-                throw rsgis::RSGISImageException(message.c_str());
-            }
-            
-            GDALDataset *imgValsDS = (GDALDataset *) GDALOpen(valsImage.c_str(), GA_ReadOnly);
-            if(imgValsDS == NULL)
-            {
-                std::string message = std::string("Could not open image ") + valsImage;
-                throw rsgis::RSGISImageException(message.c_str());
-            }
-            
-            GDALDataset *outputClumpsDS = imgUtils.createCopy(clumpDS, 1, outputImage, imageFormat, GDT_UInt32);
-            outputClumpsDS->GetRasterBand(1)->Fill(0.0);
-            
-            
-            throw rsgis::RSGISException("executePxlGrowRegions is not implemented yet; see code in RSGISRegionGrowSegmentsPixels.h");
-            
-            
-            
-            outputClumpsDS->GetRasterBand(1)->SetMetadataItem("LAYER_TYPE", "thematic");
-            rsgis::rastergis::RSGISPopulateWithImageStats popImageStats;
-            popImageStats.populateImageWithRasterGISStats(outputClumpsDS, true, true, true, 1);
-            
-            // Tidy up
-            GDALClose(clumpDS);
-            GDALClose(imgValsDS);
-            GDALClose(outputClumpsDS);
-        }
-        catch (rsgis::RSGISException &e)
-        {
-            throw rsgis::cmds::RSGISCmdException(e.what());
-        }
-        catch (std::exception &e)
-        {
-            throw rsgis::cmds::RSGISCmdException(e.what());
-        }
-    }
+
     
 }}
 
