@@ -31,7 +31,7 @@ namespace rsgis
             calc = valueCalc;
         }
             
-        void RSGISCalcEditImage::calcImage(GDALDataset *dataset) throw(RSGISImageCalcException,RSGISImageBandException)
+        void RSGISCalcEditImage::calcImage(GDALDataset *dataset)
         {
             RSGISImageUtils imgUtils;
             double *gdalTranslation = new double[6];
@@ -67,7 +67,7 @@ namespace rsgis
                 }
                 inDataColumn = new float[numInBands];
                 
-                geos::geom::Envelope extent;
+                OGREnvelope extent;
                 double pxlTLX = 0;
                 double pxlTLY = 0;
                 double pxlWidth = 0;
@@ -83,17 +83,11 @@ namespace rsgis
                     pxlHeight *= (-1);
                 }
                 
-                int feedback = height/10;
-                int feedbackCounter = 0;
-                std::cout << "Started " << std::flush;
+                rsgis_tqdm pbar;
                 // Loop images to process data
                 for(int i = 0; i < height; i++)
                 {
-                    if((i % feedback) == 0)
-                    {
-                        std::cout << ".." << feedbackCounter << ".." << std::flush;
-                        feedbackCounter = feedbackCounter + 10;
-                    }
+                    pbar.progress(i, height);
                     
                     for(int n = 0; n < numInBands; n++)
                     {
@@ -107,7 +101,10 @@ namespace rsgis
                             inDataColumn[n] = inputData[n][j];
                         }
                         
-                        extent.init(pxlTLX, (pxlTLX+pxlWidth), pxlTLY, (pxlTLY-pxlHeight));
+                        extent.MinX = pxlTLX;
+                        extent.MaxX = (pxlTLX+pxlWidth);
+                        extent.MinY = pxlTLY;
+                        extent.MaxY = (pxlTLY-pxlHeight);
                         this->calc->calcImageValue(inDataColumn, numInBands, extent);
                         
                         for(int n = 0; n < numInBands; n++)
@@ -126,7 +123,7 @@ namespace rsgis
                     pxlTLY -= pxlHeight;
                     pxlTLX = gdalTranslation[0];
                 }
-                std::cout << " Complete.\n";
+                pbar.finish();
             }
             catch(RSGISImageCalcException& e)
             {
@@ -211,7 +208,7 @@ namespace rsgis
             }
         }
         
-        void RSGISCalcEditImage::calcImageUseOut(GDALDataset *dataset) throw(RSGISImageCalcException,RSGISImageBandException)
+        void RSGISCalcEditImage::calcImageUseOut(GDALDataset *dataset)
         {
             RSGISImageUtils imgUtils;
             
@@ -242,9 +239,7 @@ namespace rsgis
                 }
 
                 rasterBands[0]->GetBlockSize (&xBlockSize, &yBlockSize);
-                
-                std::cout << "Max. block size: " << yBlockSize << std::endl;
-                
+                                
                 // Allocate memory
                 inputData = new float*[numBands];
                 for(int i = 0; i < numBands; i++)
@@ -264,9 +259,7 @@ namespace rsgis
                 int remainRows = height - (nYBlocks * yBlockSize);
                 int rowOffset = 0;
                 
-                int feedback = height/10.0;
-                int feedbackCounter = 0;
-                std::cout << "Started " << std::flush;
+                rsgis_tqdm pbar;
                 // Loop images to process data
                 for(int i = 0; i < nYBlocks; i++)
                 {
@@ -278,12 +271,7 @@ namespace rsgis
                     
                     for(int m = 0; m < yBlockSize; ++m)
                     {
-                        if((feedback != 0) && (((i*yBlockSize)+m) % feedback) == 0)
-                        {
-                            std::cout << "." << feedbackCounter << "." << std::flush;
-                            feedbackCounter = feedbackCounter + 10;
-                        }
-                        
+                        pbar.progress((i*yBlockSize)+m, height);
                         
                         for(int j = 0; j < width; j++)
                         {
@@ -319,11 +307,7 @@ namespace rsgis
                     
                     for(int m = 0; m < remainRows; ++m)
                     {
-                        if((feedback != 0) && ((((nYBlocks*yBlockSize)+m) % feedback) == 0))
-                        {
-                            std::cout << "." << feedbackCounter << "." << std::flush;
-                            feedbackCounter = feedbackCounter + 10;
-                        }
+                        pbar.progress((nYBlocks*yBlockSize)+m, height);
                         
                         for(int j = 0; j < width; j++)
                         {
@@ -348,7 +332,7 @@ namespace rsgis
                         rasterBands[n]->RasterIO(GF_Write, 0, rowOffset, width, remainRows, outputData[n], width, remainRows, GDT_Float32, 0, 0);
                     }
                 }
-                std::cout << " Complete.\n";
+                pbar.finish();
             }
             catch(RSGISImageCalcException& e)
             {                
@@ -476,7 +460,7 @@ namespace rsgis
             }
         }
         
-        void RSGISCalcEditImage::calcImageWindowData(GDALDataset *dataset, int windowSize, float fillval) throw(RSGISImageCalcException,RSGISImageBandException)
+        void RSGISCalcEditImage::calcImageWindowData(GDALDataset *dataset, int windowSize, float fillval)
         {
             if(dataset == NULL)
             {
@@ -591,9 +575,7 @@ namespace rsgis
                 int dWinX = 0;
                 int dWinY = 0;
                 
-                int feedback = height/10.0;
-                int feedbackCounter = 0;
-                std::cout << "Started " << std::flush;
+                rsgis_tqdm pbar;
                 
                 if(nYBlocks > 0)
                 {
@@ -717,12 +699,8 @@ namespace rsgis
                         
                         for(int m = 0; m < numOfLines; ++m)
                         {
+                            pbar.progress((i*yBlockSize)+m, height);
                             line = (i*numOfLines)+m;
-                            if((feedback != 0) && (line % feedback) == 0)
-                            {
-                                std::cout << "." << feedbackCounter << "." << std::flush;
-                                feedbackCounter = feedbackCounter + 10;
-                            }
                             
                             cLinePxl = m*width;
                             
@@ -948,11 +926,7 @@ namespace rsgis
                         {
                             line = (nYBlocks*numOfLines)+m;
 
-                            if((feedback != 0) && (line % feedback) == 0)
-                            {
-                                std::cout << "." << feedbackCounter << "." << std::flush;
-                                feedbackCounter = feedbackCounter + 10;
-                            }
+                            pbar.progress((nYBlocks*yBlockSize)+m, height);
                             
                             cLinePxl = m*width;
                             
@@ -1145,13 +1119,7 @@ namespace rsgis
                     }
                     
                 }
-                else
-                {
-                    
-                }
-                
-                
-                std::cout << " Complete.\n";
+                pbar.finish();
             }
             catch(RSGISImageCalcException& e)
             {
