@@ -32,7 +32,7 @@ namespace rsgis{namespace img{
         
     }
     
-    void RSGISExtractImageValues::extractDataWithinMask2HDF(GDALDataset *mask, GDALDataset *image, std::string outHDFFile, float maskValue) throw(RSGISImageException)
+    void RSGISExtractImageValues::extractDataWithinMask2HDF(GDALDataset *mask, GDALDataset *image, std::string outHDFFile, float maskValue, RSGISLibDataType dataType)
     {
         try
         {
@@ -57,7 +57,8 @@ namespace rsgis{namespace img{
             delete[] datasets;
             
             rsgis::utils::RSGISExportColumnData2HDF exportCols2HDF;
-            exportCols2HDF.createFile(outHDFFile, numImageBands, std::string("Pixels Extracted from ")+std::string(image->GetFileList()[0]), H5::PredType::IEEE_F32LE);
+            H5::DataType h5DataType = exportCols2HDF.getH5DataType(dataType);
+            exportCols2HDF.createFile(outHDFFile, numImageBands, std::string("Pixels Extracted from ")+std::string(image->GetFileList()[0]), h5DataType);
             float *row = new float[numImageBands];
             for(unsigned int j = 0; j < pxlVals->size(); ++j)
             {
@@ -90,7 +91,7 @@ namespace rsgis{namespace img{
         }
     }
     
-    void RSGISExtractImageValues::extractImgBandDataWithinMask2HDF(std::vector<std::pair<std::string, std::vector<unsigned int> > > imageFiles, std::string maskImage, std::string outHDFFile, float maskValue) throw(RSGISImageException)
+    void RSGISExtractImageValues::extractImgBandDataWithinMask2HDF(std::vector<std::pair<std::string, std::vector<unsigned int> > > imageFiles, std::string maskImage, std::string outHDFFile, float maskValue, RSGISLibDataType dataType)
     {
         try
         {
@@ -154,7 +155,8 @@ namespace rsgis{namespace img{
             delete[] datasets;
             
             rsgis::utils::RSGISExportColumnData2HDF exportCols2HDF;
-            exportCols2HDF.createFile(outHDFFile, numOutImgBands, std::string("Pixels Extracted"), H5::PredType::IEEE_F32LE);
+            H5::DataType h5DataType = exportCols2HDF.getH5DataType(dataType);
+            exportCols2HDF.createFile(outHDFFile, numOutImgBands, std::string("Pixels Extracted"), h5DataType);
             float *row = new float[numOutImgBands];
             for(unsigned int j = 0; j < pxlVals->size(); ++j)
             {
@@ -188,6 +190,229 @@ namespace rsgis{namespace img{
         }
     }
     
+    void RSGISExtractImageValues::sampleExtractedHDFData(std::string inputH5, std::string outputH5, unsigned int nSamples, int seed, RSGISLibDataType dataType)
+    {
+        try
+        {
+            rsgis::utils::RSGISReadHDFColumnData readHDFCol;
+            readHDFCol.openFile(inputH5);
+            unsigned int nRows = readHDFCol.getNumRows();
+            unsigned int nCols = readHDFCol.getNumCols();
+
+            if(nRows > nSamples)
+            {
+                unsigned int blockSize = 1000;
+                unsigned int nFullBlocks = (int)floor(((double)nRows)/((double)blockSize));
+                unsigned int remain = nRows - (blockSize*nFullBlocks);
+                float *dataBlock = new float[nRows*nCols];
+
+                float propSamples = ((float)nSamples) / ((float)nRows);
+
+                unsigned int samplesPerBlock = (unsigned int)(ceil(((float)blockSize) * propSamples));
+                unsigned int samples4Remain = (unsigned int)(ceil(((float)remain) * propSamples));
+                //unsigned int totalSamples = (samplesPerBlock * nFullBlocks) + samples4Remain;
+
+                rsgis::utils::RSGISExportColumnData2HDF exportCols2HDF;
+                H5::DataType h5DataType = exportCols2HDF.getH5DataType(dataType);
+                exportCols2HDF.createFile(outputH5, nCols, std::string("Sampled Pixels Extracted"), h5DataType);
+                float *row = new float[nCols];
+
+                boost::mt19937 randomGen;
+                randomGen.seed(seed);
+                boost::uniform_int<> randomDist(0, blockSize);
+                boost::variate_generator<boost::mt19937&, boost::uniform_int<> > randomVal(randomGen, randomDist);
+
+                unsigned int ranIdx = 0;
+                unsigned int nRowsOff = 0;
+                for(unsigned int i = 0; i < nFullBlocks; ++i)
+                {
+                    readHDFCol.getDataRows(dataBlock, nCols, blockSize, H5::PredType::NATIVE_FLOAT, nRowsOff, blockSize);
+
+                    for(unsigned int j = 0; j < samplesPerBlock; ++j)
+                    {
+                        ranIdx = randomVal();
+                        for(unsigned int n = 0; n < nCols; ++n)
+                        {
+                            row[n] = dataBlock[(ranIdx*nCols)+n];
+                        }
+                        exportCols2HDF.addDataRow(row, H5::PredType::NATIVE_FLOAT);
+                    }
+                    nRowsOff += blockSize;
+                }
+                if(remain > 0)
+                {
+                    boost::uniform_int<> randomDist(0, remain);
+                    boost::variate_generator<boost::mt19937&, boost::uniform_int<> > randomVal(randomGen, randomDist);
+
+                    readHDFCol.getDataRows(dataBlock, nCols, blockSize, H5::PredType::NATIVE_FLOAT, nRowsOff, remain);
+                    for(unsigned int j = 0; j < samples4Remain; ++j)
+                    {
+                        ranIdx = randomVal();
+                        for(unsigned int n = 0; n < nCols; ++n)
+                        {
+                            row[n] = dataBlock[(ranIdx*nCols)+n];
+                        }
+                        exportCols2HDF.addDataRow(row, H5::PredType::NATIVE_FLOAT);
+                    }
+                }
+                exportCols2HDF.close();
+                delete[] row;
+                delete[] dataBlock;
+            }
+            else
+            {
+                throw RSGISException("There are not enough rows to create that sample.");
+            }
+            readHDFCol.close();
+        }
+        catch (RSGISException &e)
+        {
+            throw e;
+        }
+        catch (std::exception &e)
+        {
+            throw RSGISException(e.what());
+        }
+    }
+
+    void RSGISExtractImageValues::splitExtractedHDFData(std::string inputH5, std::string outputP1H5, std::string outputP2H5, unsigned int nSamples, int seed, RSGISLibDataType dataType)
+    {
+        try
+        {
+            rsgis::utils::RSGISReadHDFColumnData readHDFCol;
+            readHDFCol.openFile(inputH5);
+            unsigned int nRows = readHDFCol.getNumRows();
+            unsigned int nCols = readHDFCol.getNumCols();
+
+            if(nRows > nSamples)
+            {
+                unsigned int blockSize = 1000;
+                unsigned int nFullBlocks = (int)floor(((double)nRows)/((double)blockSize));
+                unsigned int remain = nRows - (blockSize*nFullBlocks);
+                float *dataBlock = new float[nRows*nCols];
+
+                float propSamples = ((float)nSamples) / ((float)nRows);
+
+                unsigned int samplesPerBlock = (unsigned int)(ceil(((float)blockSize) * propSamples));
+                unsigned int samples4Remain = (unsigned int)(ceil(((float)remain) * propSamples));
+                //unsigned int totalSamples = (samplesPerBlock * nFullBlocks) + samples4Remain;
+
+                rsgis::utils::RSGISExportColumnData2HDF exportCols2HDF_P1;
+                H5::DataType h5DataType = exportCols2HDF_P1.getH5DataType(dataType);
+                exportCols2HDF_P1.createFile(outputP1H5, nCols, std::string("Sampled Pixels Extracted"), h5DataType);
+                rsgis::utils::RSGISExportColumnData2HDF exportCols2HDF_P2;
+                exportCols2HDF_P2.createFile(outputP2H5, nCols, std::string("Sampled Pixels Extracted"), h5DataType);
+                float *row = new float[nCols];
+                unsigned int *ranIdxes = new unsigned int[samplesPerBlock];
+
+                boost::mt19937 randomGen;
+                randomGen.seed(seed);
+                boost::uniform_int<> randomDist(0, blockSize);
+                boost::variate_generator<boost::mt19937&, boost::uniform_int<> > randomVal(randomGen, randomDist);
+
+                bool found = false;
+                unsigned int ranIdx = 0;
+                unsigned int nRowsOff = 0;
+                for(unsigned int i = 0; i < nFullBlocks; ++i)
+                {
+                    readHDFCol.getDataRows(dataBlock, nCols, blockSize, H5::PredType::NATIVE_FLOAT, nRowsOff, blockSize);
+
+                    for(unsigned int j = 0; j < samplesPerBlock; ++j)
+                    {
+                        ranIdx = randomVal();
+                        for(unsigned int n = 0; n < nCols; ++n)
+                        {
+                            row[n] = dataBlock[(ranIdx*nCols)+n];
+                        }
+                        exportCols2HDF_P1.addDataRow(row, H5::PredType::NATIVE_FLOAT);
+                        ranIdxes[j] = ranIdx;
+                    }
+
+                    for(unsigned int j = 0; j < blockSize; ++j)
+                    {
+                        found = false;
+                        for(unsigned int k = 0; k < samplesPerBlock; ++k)
+                        {
+                            if(ranIdxes[k] == j)
+                            {
+                                found = true;
+                                break;
+                            }
+                        }
+
+                        if(!found)
+                        {
+                            for(unsigned int n = 0; n < nCols; ++n)
+                            {
+                                row[n] = dataBlock[(j*nCols)+n];
+                            }
+                            exportCols2HDF_P2.addDataRow(row, H5::PredType::NATIVE_FLOAT);
+                        }
+                    }
+
+                    nRowsOff += blockSize;
+                }
+                if(remain > 0)
+                {
+                    boost::uniform_int<> randomDist(0, remain);
+                    boost::variate_generator<boost::mt19937&, boost::uniform_int<> > randomVal(randomGen, randomDist);
+
+                    readHDFCol.getDataRows(dataBlock, nCols, blockSize, H5::PredType::NATIVE_FLOAT, nRowsOff, remain);
+                    for(unsigned int j = 0; j < samples4Remain; ++j)
+                    {
+                        ranIdx = randomVal();
+                        for(unsigned int n = 0; n < nCols; ++n)
+                        {
+                            row[n] = dataBlock[(ranIdx*nCols)+n];
+                        }
+                        exportCols2HDF_P1.addDataRow(row, H5::PredType::NATIVE_FLOAT);
+                        ranIdxes[j] = ranIdx;
+                    }
+
+                    for(unsigned int j = 0; j < remain; ++j)
+                    {
+                        found = false;
+                        for(unsigned int k = 0; k < samples4Remain; ++k)
+                        {
+                            if(ranIdxes[k] == j)
+                            {
+                                found = true;
+                                break;
+                            }
+                        }
+
+                        if(!found)
+                        {
+                            for(unsigned int n = 0; n < nCols; ++n)
+                            {
+                                row[n] = dataBlock[(j*nCols)+n];
+                            }
+                            exportCols2HDF_P2.addDataRow(row, H5::PredType::NATIVE_FLOAT);
+                        }
+                    }
+                }
+                exportCols2HDF_P1.close();
+                exportCols2HDF_P2.close();
+                delete[] row;
+                delete[] dataBlock;
+                delete[] ranIdxes;
+            }
+            else
+            {
+                throw RSGISException("There are not enough rows to create that sample.");
+            }
+            readHDFCol.close();
+        }
+        catch (RSGISException &e)
+        {
+            throw e;
+        }
+        catch (std::exception &e)
+        {
+            throw RSGISException(e.what());
+        }
+    }
+
     RSGISExtractImageValues::~RSGISExtractImageValues()
     {
         
@@ -201,7 +426,7 @@ namespace rsgis{namespace img{
         this->maskValue = maskValue;
     }
     
-    void RSGISExtractImageValuesWithMask::calcImageValue(float *bandValues, int numBands) throw(RSGISImageCalcException)
+    void RSGISExtractImageValuesWithMask::calcImageValue(float *bandValues, int numBands) 
     {
         if(bandValues[0] == maskValue)
         {
@@ -233,7 +458,7 @@ namespace rsgis{namespace img{
         this->numOutVals = this->imgBands.size();
     }
     
-    void RSGISExtractImageBandValuesWithMask::calcImageValue(float *bandValues, int numBands) throw(RSGISImageCalcException)
+    void RSGISExtractImageBandValuesWithMask::calcImageValue(float *bandValues, int numBands) 
     {
         if(bandValues[0] == maskValue)
         {
@@ -263,7 +488,7 @@ namespace rsgis{namespace img{
         
     }
     
-    void RSGISExtractPxlsAsPts::exportPixelsAsPoints(GDALDataset *image, OGRLayer *vecLayer, float maskVal) throw(RSGISImageException)
+    void RSGISExtractPxlsAsPts::exportPixelsAsPoints(GDALDataset *image, OGRLayer *vecLayer, float maskVal)
     {
         try
         {
@@ -288,7 +513,7 @@ namespace rsgis{namespace img{
         }
     }
     
-    void RSGISExtractPxlsAsPts::exportPixelsAsPoints(GDALDataset *image, float maskVal, std::vector<std::pair<double,double> > *pxPts, geos::geom::Envelope *env) throw(RSGISImageException)
+    void RSGISExtractPxlsAsPts::exportPixelsAsPoints(GDALDataset *image, float maskVal, std::vector<std::pair<double,double> > *pxPts, OGREnvelope *env)
     {
         try
         {
@@ -318,7 +543,7 @@ namespace rsgis{namespace img{
         }
     }
     
-    void RSGISExtractPxlsAsPts::exportPixelsAsPointsWithVal(GDALDataset *image, float maskVal, GDALDataset *valImg, int valImgBand, std::vector<std::pair<std::pair<double,double>,double> > *pxPts, bool quiet, geos::geom::Envelope *env) throw(RSGISImageException)
+    void RSGISExtractPxlsAsPts::exportPixelsAsPointsWithVal(GDALDataset *image, float maskVal, GDALDataset *valImg, int valImgBand, std::vector<std::pair<std::pair<double,double>,double> > *pxPts, bool quiet, OGREnvelope *env)
     {
         try
         {
@@ -372,15 +597,15 @@ namespace rsgis{namespace img{
         this->featDefn = vecLayer->GetLayerDefn();
     }
     
-    void RSGISExtractPxlsAsPtsImgCalc::calcImageValue(float *bandValues, int numBands, geos::geom::Envelope extent) throw(RSGISImageCalcException)
+    void RSGISExtractPxlsAsPtsImgCalc::calcImageValue(float *bandValues, int numBands, OGREnvelope extent) 
     {
         if(bandValues[0] == maskValue)
         {
-            geos::geom::Coordinate centre;
-            extent.centre(centre);
+            double centre_x = extent.MinX + (extent.MaxX - extent.MinX)/2;
+            double centre_y = extent.MinY + (extent.MaxY - extent.MinY)/2;
             
             OGRFeature *poFeature = new OGRFeature(featDefn);
-            OGRPoint *pt = new OGRPoint(centre.x, centre.y, 0.0);
+            OGRPoint *pt = new OGRPoint(centre_x, centre_y, 0.0);
             poFeature->SetGeometryDirectly(pt);
             vecLayer->CreateFeature(poFeature);
         }
@@ -399,13 +624,13 @@ namespace rsgis{namespace img{
         this->maskValue = maskValue;
     }
     
-    void RSGISExtractPxlsAsPts2VecImgCalc::calcImageValue(float *bandValues, int numBands, geos::geom::Envelope extent) throw(RSGISImageCalcException)
+    void RSGISExtractPxlsAsPts2VecImgCalc::calcImageValue(float *bandValues, int numBands, OGREnvelope extent) 
     {
         if(bandValues[0] == maskValue)
         {
-            geos::geom::Coordinate centre;
-            extent.centre(centre);
-            pxPts->push_back(std::pair<double,double>(centre.x, centre.y));
+            double centre_x = extent.MinX + (extent.MaxX - extent.MinX)/2;
+            double centre_y = extent.MinY + (extent.MaxY - extent.MinY)/2;
+            pxPts->push_back(std::pair<double,double>(centre_x, centre_y));
         }
     }
     
@@ -421,13 +646,13 @@ namespace rsgis{namespace img{
         this->valIdx = valIdx;
     }
     
-    void RSGISExtractPxlsAsPts2VecWithValImgCalc::calcImageValue(float *bandValues, int numBands, geos::geom::Envelope extent) throw(RSGISImageCalcException)
+    void RSGISExtractPxlsAsPts2VecWithValImgCalc::calcImageValue(float *bandValues, int numBands, OGREnvelope extent) 
     {
         if(bandValues[0] == maskValue)
         {
-            geos::geom::Coordinate centre;
-            extent.centre(centre);
-            pxPts->push_back(std::pair<std::pair<double,double>, double>(std::pair<double,double>(centre.x, centre.y), bandValues[valIdx]));
+            double centre_x = extent.MinX + (extent.MaxX - extent.MinX)/2;
+            double centre_y = extent.MinY + (extent.MaxY - extent.MinY)/2;
+            pxPts->push_back(std::pair<std::pair<double,double>, double>(std::pair<double,double>(centre_x, centre_y), bandValues[valIdx]));
         }
     }
     
