@@ -30,7 +30,7 @@ namespace rsgis{namespace math{
 		
 	}
 	
-	double RSGISMathsUtils::strtodouble(std::string inValue)throw(RSGISMathException)
+	double RSGISMathsUtils::strtodouble(std::string inValue)
 	{
 		double outValue = 0;
 		try
@@ -45,7 +45,7 @@ namespace rsgis{namespace math{
 		return outValue;
 	}
 	
-	float RSGISMathsUtils::strtofloat(std::string inValue)throw(RSGISMathException)
+	float RSGISMathsUtils::strtofloat(std::string inValue)
 	{
 		float outValue = 0;
 		try
@@ -60,7 +60,7 @@ namespace rsgis{namespace math{
 		return outValue;
 	}
 	
-	int RSGISMathsUtils::strtoint(std::string inValue)throw(RSGISMathException)
+	int RSGISMathsUtils::strtoint(std::string inValue)
 	{
 		int outValue = 0;
 		try
@@ -75,7 +75,7 @@ namespace rsgis{namespace math{
 		return outValue;
 	}
 	
-	unsigned int RSGISMathsUtils::strtounsignedint(std::string inValue)throw(RSGISMathException)
+	unsigned int RSGISMathsUtils::strtounsignedint(std::string inValue)
 	{
 		unsigned int outValue = 0;
 		try
@@ -90,7 +90,7 @@ namespace rsgis{namespace math{
 		return outValue;
 	}
 	
-	long RSGISMathsUtils::strtolong(std::string inValue)throw(RSGISMathException)
+	long RSGISMathsUtils::strtolong(std::string inValue)
 	{
 		long outValue = 0;
 		try
@@ -105,7 +105,7 @@ namespace rsgis{namespace math{
 		return outValue;
 	}
     
-    unsigned long RSGISMathsUtils::strtounsignedlong(std::string inValue)throw(RSGISMathException)
+    unsigned long RSGISMathsUtils::strtounsignedlong(std::string inValue)
 	{
 		unsigned long outValue = 0;
 		try
@@ -120,7 +120,7 @@ namespace rsgis{namespace math{
 		return outValue;
 	}
 	
-	std::string RSGISMathsUtils::floattostring(float number)throw(RSGISMathException)
+	std::string RSGISMathsUtils::floattostring(float number)
 	{
 		std::string outValue = "";
 		try
@@ -134,7 +134,7 @@ namespace rsgis{namespace math{
 		return outValue;
 	}
 	
-	std::string RSGISMathsUtils::doubletostring(double number)throw(RSGISMathException)
+	std::string RSGISMathsUtils::doubletostring(double number)
 	{
 		std::string outValue = "";
 		try
@@ -148,7 +148,7 @@ namespace rsgis{namespace math{
 		return outValue;
 	}
 	
-	std::string RSGISMathsUtils::inttostring(int number)throw(RSGISMathException)
+	std::string RSGISMathsUtils::inttostring(int number)
 	{
 		std::string outValue = "";
 		try
@@ -162,7 +162,7 @@ namespace rsgis{namespace math{
 		return outValue;
 	}
     
-    std::string RSGISMathsUtils::uinttostring(unsigned int number)throw(RSGISMathException)
+    std::string RSGISMathsUtils::uinttostring(unsigned int number)
 	{
         std::string outValue = "";
 		try
@@ -176,7 +176,7 @@ namespace rsgis{namespace math{
 		return outValue;
 	}
 	
-	std::string RSGISMathsUtils::longtostring(long number)throw(RSGISMathException)
+	std::string RSGISMathsUtils::longtostring(long number)
 	{
 		std::string outValue = "";
 		try
@@ -200,7 +200,7 @@ namespace rsgis{namespace math{
 		return angle * (180 / M_PI);
 	}
 	
-	void RSGISMathsUtils::getPowerSet(int numItems, int *numBands, int **indexes, int numSets) throw(RSGISMathException)
+	void RSGISMathsUtils::getPowerSet(int numItems, int *numBands, int **indexes, int numSets)
 	{
 		if(numItems == 0)
 		{
@@ -533,7 +533,7 @@ namespace rsgis{namespace math{
 		return outData;
 	}
     
-    void RSGISMathsUtils::fitPlane(double *x, double *y, double *z, unsigned int numValues, double *a, double *b, double *c) throw(RSGISMathException)
+    void RSGISMathsUtils::fitPlane(double *x, double *y, double *z, unsigned int numValues, double *a, double *b, double *c)
     {
         RSGISMatrices matrices;
 		Matrix *matrixA = NULL;
@@ -589,7 +589,7 @@ namespace rsgis{namespace math{
 			*b = outputs->matrix[1];
 			*c = outputs->matrix[2];
 		}
-		catch(RSGISMatricesException e)
+		catch(RSGISMatricesException &e)
 		{
 			if(matrixA != NULL)
 			{
@@ -621,7 +621,7 @@ namespace rsgis{namespace math{
         matrices.freeMatrix(outputs);
     }
     
-    void RSGISMathsUtils::generateStats(std::vector<double> *data, RSGISStatsSummary *stats) throw(RSGISMathException)
+    void RSGISMathsUtils::generateStats(std::vector<double> *data, RSGISStatsSummary *stats)
     {
         try
         {
@@ -682,40 +682,48 @@ namespace rsgis{namespace math{
                     double minVal = 0.0;
                     double maxVal = 0.0;
                     gsl_stats_minmax (&minVal, &maxVal, &(*data)[0], 1, data->size());
-                    long minBin = floor(minVal);
-                    long maxBin = floor(maxVal+1);
-                    long numBins = maxBin - minBin;
-                    long *bins = new long[numBins];
-                    for(long i = 0; i < numBins; ++i)
-                    {
-                        bins[i] = 0;
-                    }
                     
-                    long tmpVal = 0;
-                    long tmpBin = 0;
-                    for(std::vector<double>::iterator iterVals = data->begin(); iterVals != data->end(); ++iterVals)
+                    if(minVal == maxVal)
                     {
-                        tmpVal = floor(*iterVals);
-                        tmpBin = tmpVal - minBin;
-                        ++bins[tmpBin];
+                        stats->mode = floor(minVal);
                     }
-                    
-                    long maxFreqBinIdx = 0;
-                    for(long i = 0; i < numBins; ++i)
+                    else
                     {
-                        if(i == 0)
+                        long minBin = floor(minVal);
+                        long maxBin = floor(maxVal+1);
+                        
+                        long numBins = maxBin - minBin;
+                        long *bins = new long[numBins];
+                        for(long i = 0; i < numBins; ++i)
                         {
-                            maxFreqBinIdx = 0;
+                            bins[i] = 0;
                         }
-                        else if(bins[i] > bins[maxFreqBinIdx])
+                        
+                        long tmpVal = 0;
+                        long tmpBin = 0;
+                        for(std::vector<double>::iterator iterVals = data->begin(); iterVals != data->end(); ++iterVals)
                         {
-                            maxFreqBinIdx = i;
+                            tmpVal = floor(*iterVals);
+                            tmpBin = tmpVal - minBin;
+                            ++bins[tmpBin];
                         }
+                        
+                        long maxFreqBinIdx = 0;
+                        for(long i = 0; i < numBins; ++i)
+                        {
+                            if(i == 0)
+                            {
+                                maxFreqBinIdx = 0;
+                            }
+                            else if(bins[i] > bins[maxFreqBinIdx])
+                            {
+                                maxFreqBinIdx = i;
+                            }
+                        }
+                        stats->mode = minBin + maxFreqBinIdx;
+                        
+                        delete[] bins;
                     }
-                    
-                    stats->mode = minBin + maxFreqBinIdx;
-                    
-                    delete[] bins;
                 }
             }
             else
@@ -822,7 +830,7 @@ namespace rsgis{namespace math{
         return withinRange;
     }
     
-    double RSGISMathsUtils::calcPercentile(float percentile, double *binBounds, double binWidth, unsigned int numBins, unsigned int *hist) throw(RSGISMathException)
+    double RSGISMathsUtils::calcPercentile(float percentile, double *binBounds, double binWidth, unsigned int numBins, unsigned int *hist)
     {
         double percentVal = 0.0;
         try
@@ -880,7 +888,7 @@ namespace rsgis{namespace math{
         return percentVal;
     }
     
-    double RSGISMathsUtils::calcPercentile(float percentile, double histMinVal, double binWidth, unsigned int numBins, unsigned int *hist) throw(RSGISMathException)
+    double RSGISMathsUtils::calcPercentile(float percentile, double histMinVal, double binWidth, unsigned int numBins, unsigned int *hist)
     {
         double percentVal = 0.0;
         try
@@ -938,7 +946,7 @@ namespace rsgis{namespace math{
         return percentVal;
     }
 
-    double* RSGISMathsUtils::calcMeanVector(double **data, size_t n, size_t m, size_t sMIdx, size_t eMIdx) throw(RSGISMathException)
+    double* RSGISMathsUtils::calcMeanVector(double **data, size_t n, size_t m, size_t sMIdx, size_t eMIdx)
     {
         size_t numVals = eMIdx - sMIdx;
         double *meanVec = new double[numVals];
@@ -978,7 +986,7 @@ namespace rsgis{namespace math{
         return meanVec;
     }
     
-    double** RSGISMathsUtils::calcCovarianceMatrix(double **data, double *meanVec, size_t n, size_t m, size_t sMIdx, size_t eMIdx) throw(RSGISMathException)
+    double** RSGISMathsUtils::calcCovarianceMatrix(double **data, double *meanVec, size_t n, size_t m, size_t sMIdx, size_t eMIdx)
     {
         size_t numVals = eMIdx - sMIdx;
         double **covarMatrix = new double*[numVals];
@@ -1027,7 +1035,7 @@ namespace rsgis{namespace math{
     }
     
     
-    std::vector<std::pair<size_t, double> >* RSGISMathsUtils::sampleUseHistogramMethod(std::vector<std::pair<size_t, double> > *inData, double minVal, double maxVal, double binWidth, float propOfPop) throw(RSGISMathException)
+    std::vector<std::pair<size_t, double> >* RSGISMathsUtils::sampleUseHistogramMethod(std::vector<std::pair<size_t, double> > *inData, double minVal, double maxVal, double binWidth, float propOfPop)
     {
         std::vector<std::pair<size_t, double> > *outData = new std::vector<std::pair<size_t, double> >();
         try
@@ -1091,7 +1099,7 @@ namespace rsgis{namespace math{
         return outData;
     }
     
-    std::vector<std::pair<size_t, double> >** RSGISMathsUtils::calcHistogram(std::vector<std::pair<size_t, double> > *inData, double minVal, double maxVal, double binWidth, size_t *numBins) throw(RSGISMathException)
+    std::vector<std::pair<size_t, double> >** RSGISMathsUtils::calcHistogram(std::vector<std::pair<size_t, double> > *inData, double minVal, double maxVal, double binWidth, size_t *numBins)
     {
         std::vector<std::pair<size_t, double> > **hist = NULL;
         try
@@ -1131,7 +1139,7 @@ namespace rsgis{namespace math{
     }
     
     
-    std::vector<std::pair<double, double> >* RSGISMathsUtils::calcHistogram(std::vector<double> *data, double minVal, double maxVal, double binWidth, bool norm) throw(RSGISMathException)
+    std::vector<std::pair<double, double> >* RSGISMathsUtils::calcHistogram(std::vector<double> *data, double minVal, double maxVal, double binWidth, bool norm)
     {
         std::vector<std::pair<double, double> > *hist = new std::vector<std::pair<double, double> >();
         try
@@ -1182,7 +1190,7 @@ namespace rsgis{namespace math{
     }
     
     
-    std::vector<std::vector<RSGIS2DHistBin>* >* RSGISMathsUtils::calc2DHistogram(std::vector<double> *data1, double minVal1, double maxVal1, double binWidth1, std::vector<double> *data2, double minVal2, double maxVal2, double binWidth2, bool norm) throw(RSGISMathException)
+    std::vector<std::vector<RSGIS2DHistBin>* >* RSGISMathsUtils::calc2DHistogram(std::vector<double> *data1, double minVal1, double maxVal1, double binWidth1, std::vector<double> *data2, double minVal2, double maxVal2, double binWidth2, bool norm)
     {
         std::vector<std::vector<RSGIS2DHistBin>* > *hist = new std::vector<std::vector<RSGIS2DHistBin>* >();
         try
@@ -1259,7 +1267,7 @@ namespace rsgis{namespace math{
     }
     
     
-    unsigned int* RSGISMathsUtils::calcHistogram(double *data, size_t numVals, double binWidth, double *minVal, double *maxVal, unsigned int *numBins, bool ignoreFirstVal) throw(RSGISMathException)
+    unsigned int* RSGISMathsUtils::calcHistogram(double *data, size_t numVals, double binWidth, double *minVal, double *maxVal, unsigned int *numBins, bool ignoreFirstVal)
     {
         unsigned int *hist = NULL;
         try
@@ -1337,7 +1345,7 @@ namespace rsgis{namespace math{
         return hist;
     }
     
-    RSGISLinearFitVals* RSGISMathsUtils::performLinearFit(double *xData, double *yData, size_t nVals, double noDataVal) throw(RSGISMathException)
+    RSGISLinearFitVals* RSGISMathsUtils::performLinearFit(double *xData, double *yData, size_t nVals, double noDataVal)
     {
         RSGISLinearFitVals *fitVals = new RSGISLinearFitVals();
         try
@@ -1412,7 +1420,7 @@ namespace rsgis{namespace math{
         return fitVals;
     }
     
-    void RSGISMathsUtils::performLinearFit(double *xData, double *yData, size_t nVals, double noDataVal, RSGISLinearFitVals *fitVals) throw(RSGISMathException)
+    void RSGISMathsUtils::performLinearFit(double *xData, double *yData, size_t nVals, double noDataVal, RSGISLinearFitVals *fitVals)
     {
         try
         {
@@ -1482,7 +1490,7 @@ namespace rsgis{namespace math{
         }
     }
     
-    double RSGISMathsUtils::predFromLinearFit(double val, RSGISLinearFitVals *fitVals, double minAccVal, double maxAccVal) throw(RSGISMathException)
+    double RSGISMathsUtils::predFromLinearFit(double val, RSGISLinearFitVals *fitVals, double minAccVal, double maxAccVal)
     {
         double outVal = 0.0;
         
@@ -1504,6 +1512,108 @@ namespace rsgis{namespace math{
         
         return outVal;
     }
+
+
+
+
+
+
+void RSGISCoordsTransform::transformPoint(OGRSpatialReference *input_spat_ref, OGRSpatialReference *output_spat_ref, double inX, double inY, double *outX, double *outY)
+{
+    OGRCoordinateTransformation *poCT = OGRCreateCoordinateTransformation(input_spat_ref, output_spat_ref);
+    
+    double convert_x_val = 0.0;
+    double convert_y_val = 0.0;
+    
+    if(input_spat_ref->EPSGTreatsAsLatLong())
+    {
+        convert_x_val = inY;
+        convert_y_val = inX;
+    }
+    else
+    {
+        convert_x_val = inX;
+        convert_y_val = inY;
+    }
+    
+    if( poCT == NULL || !poCT->Transform( 1, &convert_x_val, &convert_y_val ) )
+    {
+        throw rsgis::RSGISException("Coordinate System Transformation failed.");
+    }
+    
+    if(output_spat_ref->EPSGTreatsAsLatLong())
+    {
+        (*outX) = convert_y_val;
+        (*outY) = convert_x_val;
+    }
+    else
+    {
+        (*outX) = convert_x_val;
+        (*outY) = convert_y_val;
+    }
+}
+
+void RSGISCoordsTransform::transformBBOX(OGRSpatialReference *input_spat_ref, OGRSpatialReference *output_spat_ref, OGREnvelope *inBBOX, OGREnvelope *outBBOX)
+{
+    double in_tlX = inBBOX->MinX;
+    double in_tlY = inBBOX->MaxY;
+    double out_tlX = 0.0;
+    double out_tlY = 0.0;
+    this->transformPoint(input_spat_ref, output_spat_ref, in_tlX, in_tlY, &out_tlX, &out_tlY);
+
+    double in_trX = inBBOX->MaxX;
+    double in_trY = inBBOX->MaxY;
+    double out_trX = 0.0;
+    double out_trY = 0.0;
+    this->transformPoint(input_spat_ref, output_spat_ref, in_trX, in_trY, &out_trX, &out_trY);
+    
+    double in_blX = inBBOX->MinX;
+    double in_blY = inBBOX->MinY;
+    double out_blX = 0.0;
+    double out_blY = 0.0;
+    this->transformPoint(input_spat_ref, output_spat_ref, in_blX, in_blY, &out_blX, &out_blY);
+    
+    double in_brX = inBBOX->MaxX;
+    double in_brY = inBBOX->MinY;
+    double out_brX = 0.0;
+    double out_brY = 0.0;
+    this->transformPoint(input_spat_ref, output_spat_ref, in_brX, in_brY, &out_brX, &out_brY);
+    
+    double minX = 0.0;
+    double maxX = 0.0;
+    double minY = 0.0;
+    double maxY = 0.0;
+    
+    minX = out_tlX;
+    if(out_blX < minX)
+    {
+        minX = out_blX;
+    }
+
+    maxX = out_trX;
+    if(out_brX > maxX)
+    {
+        maxX = out_brX;
+    }
+
+    minY = out_brY;
+    if(out_blY < minY)
+    {
+        minY = out_blY;
+    }
+
+    maxY = out_tlY;
+    if(out_trY > maxY)
+    {
+        maxY = out_trY;
+    }
+
+    outBBOX->MinX = minX;
+    outBBOX->MaxX = maxX;
+    outBBOX->MinY = minY;
+    outBBOX->MaxY = maxY;
+}
+
     
 }}
 
