@@ -31,7 +31,7 @@ namespace rsgis{namespace rastergis{
         
     }
     
-    void RSGISPopRATWithStats::populateRATWithBasicStats(GDALDataset *inputClumps, GDALDataset *inputValsImage, std::vector<RSGISBandAttStats*> *bandStats, unsigned int ratBand)throw(RSGISAttributeTableException)
+    void RSGISPopRATWithStats::populateRATWithBasicStats(GDALDataset *inputClumps, GDALDataset *inputValsImage, std::vector<RSGISBandAttStats*> *bandStats, unsigned int ratBand)
     {
         try
         {
@@ -73,7 +73,6 @@ namespace rsgis{namespace rastergis{
                     throw rsgis::RSGISAttributeTableException("If the standard deviation is required to be calculated then the mean must also be calculated.");
                 }
 
-                
                 if((*iterBands)->calcMin)
                 {
                     (*iterBands)->minFieldIdx = attUtils.findColumnIndexOrCreate(rat, (*iterBands)->minField, GFT_Real);
@@ -117,7 +116,20 @@ namespace rsgis{namespace rastergis{
             GDALDataset **datasets = new GDALDataset*[2];
             datasets[0] = inputClumps;
             datasets[1] = inputValsImage;
-            
+
+            int n_bands = inputValsImage->GetRasterCount();
+            double *no_data_vals = new double[n_bands];
+            bool *use_no_data_vals = new bool[n_bands];
+            int use_no_data_val_int = 0;
+            for(unsigned int i = 0; i < n_bands; ++i)
+            {
+                use_no_data_vals[i] = false;
+                use_no_data_val_int = false;
+                GDALRasterBand *image_band = inputValsImage->GetRasterBand(i+1);
+                no_data_vals[i] = image_band->GetNoDataValue(&use_no_data_val_int);
+                use_no_data_vals[i] = (bool)use_no_data_val_int;
+            }
+
             double **statsData = new double*[numRows];
             for(unsigned int i = 0; i < numRows; ++i)
             {
@@ -128,7 +140,7 @@ namespace rsgis{namespace rastergis{
                 }
             }
             
-            RSGISCalcClusterPxlValueStats *calcImgValStats = new RSGISCalcClusterPxlValueStats(statsData, bandStats, firstVal, ratBand);
+            RSGISCalcClusterPxlValueStats *calcImgValStats = new RSGISCalcClusterPxlValueStats(statsData, bandStats, firstVal, ratBand, no_data_vals, use_no_data_vals);
             rsgis::img::RSGISCalcImage calcImageStats(calcImgValStats);
             calcImageStats.calcImage(datasets, 1, 1);
             delete calcImgValStats;
@@ -324,7 +336,7 @@ namespace rsgis{namespace rastergis{
                         stdDevData[i][j] = 0.0;
                     }
                 }
-                RSGISCalcClusterPxlValueStdDev *calcImgValStdDev = new RSGISCalcClusterPxlValueStdDev(stdDevData, statsData, bandStats, firstVal, ratBand);
+                RSGISCalcClusterPxlValueStdDev *calcImgValStdDev = new RSGISCalcClusterPxlValueStdDev(stdDevData, statsData, bandStats, firstVal, ratBand, no_data_vals, use_no_data_vals);
                 rsgis::img::RSGISCalcImage calcImageStdDev(calcImgValStdDev);
                 calcImageStdDev.calcImage(datasets, 1, 1);
                 delete calcImgValStdDev;
@@ -397,7 +409,8 @@ namespace rsgis{namespace rastergis{
             }
             delete[] statsData;
             delete[] firstVal;
-            
+            delete[] no_data_vals;
+            delete[] use_no_data_vals;
             
             delete[] dataBlock;
             delete[] histDataBlock;
@@ -417,7 +430,7 @@ namespace rsgis{namespace rastergis{
         }
     }
     
-    void RSGISPopRATWithStats::populateRATWithPercentileStats(GDALDataset *inputClumps, GDALDataset *inputValsImage, unsigned int band, std::vector<RSGISBandAttPercentiles*> *bandStats, unsigned int ratBand, unsigned int numHistBins)throw(RSGISAttributeTableException)
+    void RSGISPopRATWithStats::populateRATWithPercentileStats(GDALDataset *inputClumps, GDALDataset *inputValsImage, unsigned int band, std::vector<RSGISBandAttPercentiles*> *bandStats, unsigned int ratBand, unsigned int numHistBins)
     {
         try
         {
@@ -455,8 +468,9 @@ namespace rsgis{namespace rastergis{
 
             double imageValMin = 0.0;
             double imageValMax = 0.0;
-            int nLastProgress = -1;
-            inputValsImage->GetRasterBand(band)->ComputeStatistics(false, &imageValMin, &imageValMax, NULL, NULL,  (GDALProgressFunc)RSGISRATStatsTextProgress, &nLastProgress);
+            rsgis_tqdm *pbar = new rsgis_tqdm();
+            inputValsImage->GetRasterBand(band)->ComputeStatistics(false, &imageValMin, &imageValMax, NULL, NULL,  (GDALProgressFunc)RSGISRATStatsTextProgress, pbar);
+            delete pbar;
             
             std::cout << "Image Min = " << imageValMin << " Image Max = " << imageValMax << std::endl;
             
@@ -579,7 +593,7 @@ namespace rsgis{namespace rastergis{
         }
     }
 
-    void RSGISPopRATWithStats::populateRATWithMeanLitStats(GDALDataset *inputClumps, GDALDataset *inputValsImage, GDALDataset *inputMeanLitImage, unsigned int meanLitBand, std::string meanLitCol, std::string pxlCountCol, std::vector<RSGISBandAttStats*> *bandStats, unsigned int ratBand)throw(RSGISAttributeTableException)
+    void RSGISPopRATWithStats::populateRATWithMeanLitStats(GDALDataset *inputClumps, GDALDataset *inputValsImage, GDALDataset *inputMeanLitImage, unsigned int meanLitBand, std::string meanLitCol, std::string pxlCountCol, std::vector<RSGISBandAttStats*> *bandStats, unsigned int ratBand)
     {
         try
         {
@@ -975,7 +989,7 @@ namespace rsgis{namespace rastergis{
         }
     }
     
-    void RSGISPopRATWithStats::populateRATWithModeStats(GDALDataset *inputClumps, GDALDataset *inputValsImage, std::string outColsName, bool useNoDataVal, long noDataVal, bool outNoDataVal, unsigned int modeBand, unsigned int ratBand)throw(RSGISAttributeTableException)
+    void RSGISPopRATWithStats::populateRATWithModeStats(GDALDataset *inputClumps, GDALDataset *inputValsImage, std::string outColsName, bool useNoDataVal, long noDataVal, bool outNoDataVal, unsigned int modeBand, unsigned int ratBand)
     {
         try
         {
@@ -1149,7 +1163,7 @@ namespace rsgis{namespace rastergis{
         }
     }
     
-    void RSGISPopRATWithStats::populateRATWithPopValidPixels(GDALDataset *inputClumps, GDALDataset *inputValsImage, std::string outColsName, double noDataVal, unsigned int ratBand)throw(RSGISAttributeTableException)
+    void RSGISPopRATWithStats::populateRATWithPopValidPixels(GDALDataset *inputClumps, GDALDataset *inputValsImage, std::string outColsName, double noDataVal, unsigned int ratBand)
     {
         try
         {
@@ -1232,15 +1246,17 @@ namespace rsgis{namespace rastergis{
     }
     
     
-    RSGISCalcClusterPxlValueStats::RSGISCalcClusterPxlValueStats(double **statsData, std::vector<rsgis::rastergis::RSGISBandAttStats*> *bandStats, bool *firstVal, unsigned int ratBand) : rsgis::img::RSGISCalcImageValue(0)
+    RSGISCalcClusterPxlValueStats::RSGISCalcClusterPxlValueStats(double **statsData, std::vector<rsgis::rastergis::RSGISBandAttStats*> *bandStats, bool *firstVal, unsigned int ratBand, double *no_data_vals, bool *use_no_data_vals) : rsgis::img::RSGISCalcImageValue(0)
     {
         this->statsData = statsData;
         this->bandStats = bandStats;
         this->firstVal = firstVal;
         this->ratBand = ratBand;
+        this->no_data_vals = no_data_vals;
+        this->use_no_data_vals = use_no_data_vals;
     }
     
-    void RSGISCalcClusterPxlValueStats::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISCalcClusterPxlValueStats::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) 
     {
         if(intBandValues[ratBand-1] > 0)
         {
@@ -1250,51 +1266,59 @@ namespace rsgis{namespace rastergis{
             {
                 if((boost::math::isfinite)(floatBandValues[(*iterBands)->band-1]))
                 {
-                    if((*iterBands)->calcMin)
+                    bool useVal = true;
+                    if(this->use_no_data_vals[(*iterBands)->band-1] && (this->no_data_vals[(*iterBands)->band-1] == floatBandValues[(*iterBands)->band-1]))
                     {
-                        if(firstVal[fid])
-                        {
-                            statsData[fid][(*iterBands)->minLocalIdx] = floatBandValues[(*iterBands)->band-1];
-                        }
-                        else if(floatBandValues[(*iterBands)->band-1] < statsData[fid][(*iterBands)->minLocalIdx])
-                        {
-                            statsData[fid][(*iterBands)->minLocalIdx] = floatBandValues[(*iterBands)->band-1];
-                        }
+                        useVal = false;
                     }
-                    
-                    if((*iterBands)->calcMax)
+                    if(useVal)
                     {
-                        if(firstVal[fid])
+                        if((*iterBands)->calcMin)
                         {
-                            statsData[fid][(*iterBands)->maxLocalIdx] = floatBandValues[(*iterBands)->band-1];
+                            if(firstVal[fid])
+                            {
+                                statsData[fid][(*iterBands)->minLocalIdx] = floatBandValues[(*iterBands)->band-1];
+                            }
+                            else if(floatBandValues[(*iterBands)->band-1] < statsData[fid][(*iterBands)->minLocalIdx])
+                            {
+                                statsData[fid][(*iterBands)->minLocalIdx] = floatBandValues[(*iterBands)->band-1];
+                            }
                         }
-                        else if(floatBandValues[(*iterBands)->band-1] > statsData[fid][(*iterBands)->maxLocalIdx])
+
+                        if((*iterBands)->calcMax)
                         {
-                            statsData[fid][(*iterBands)->maxLocalIdx] = floatBandValues[(*iterBands)->band-1];
+                            if(firstVal[fid])
+                            {
+                                statsData[fid][(*iterBands)->maxLocalIdx] = floatBandValues[(*iterBands)->band-1];
+                            }
+                            else if(floatBandValues[(*iterBands)->band-1] > statsData[fid][(*iterBands)->maxLocalIdx])
+                            {
+                                statsData[fid][(*iterBands)->maxLocalIdx] = floatBandValues[(*iterBands)->band-1];
+                            }
                         }
-                    }
-                    
-                    if((*iterBands)->calcMean)
-                    {
-                        if(firstVal[fid])
+
+                        if((*iterBands)->calcMean)
                         {
-                            statsData[fid][(*iterBands)->meanLocalIdx] = floatBandValues[(*iterBands)->band-1];
+                            if(firstVal[fid])
+                            {
+                                statsData[fid][(*iterBands)->meanLocalIdx] = floatBandValues[(*iterBands)->band-1];
+                            }
+                            else
+                            {
+                                statsData[fid][(*iterBands)->meanLocalIdx] += floatBandValues[(*iterBands)->band-1];
+                            }
                         }
-                        else
+
+                        if((*iterBands)->calcSum)
                         {
-                            statsData[fid][(*iterBands)->meanLocalIdx] += floatBandValues[(*iterBands)->band-1];
-                        }
-                    }
-                    
-                    if((*iterBands)->calcSum)
-                    {
-                        if(firstVal[fid])
-                        {
-                            statsData[fid][(*iterBands)->sumLocalIdx] = floatBandValues[(*iterBands)->band-1];
-                        }
-                        else
-                        {
-                            statsData[fid][(*iterBands)->sumLocalIdx] += floatBandValues[(*iterBands)->band-1];
+                            if(firstVal[fid])
+                            {
+                                statsData[fid][(*iterBands)->sumLocalIdx] = floatBandValues[(*iterBands)->band-1];
+                            }
+                            else
+                            {
+                                statsData[fid][(*iterBands)->sumLocalIdx] += floatBandValues[(*iterBands)->band-1];
+                            }
                         }
                     }
                 }
@@ -1312,16 +1336,18 @@ namespace rsgis{namespace rastergis{
         
     }
     
-    RSGISCalcClusterPxlValueStdDev::RSGISCalcClusterPxlValueStdDev(double **stdDevData, double **statsData, std::vector<rsgis::rastergis::RSGISBandAttStats*> *bandStats, bool *firstVal, unsigned int ratBand) : rsgis::img::RSGISCalcImageValue(0)
+    RSGISCalcClusterPxlValueStdDev::RSGISCalcClusterPxlValueStdDev(double **stdDevData, double **statsData, std::vector<rsgis::rastergis::RSGISBandAttStats*> *bandStats, bool *firstVal, unsigned int ratBand, double *no_data_vals, bool *use_no_data_vals) : rsgis::img::RSGISCalcImageValue(0)
     {
         this->stdDevData = stdDevData;
         this->statsData = statsData;
         this->bandStats = bandStats;
         this->firstVal = firstVal;
         this->ratBand = ratBand;
+        this->no_data_vals = no_data_vals;
+        this->use_no_data_vals = use_no_data_vals;
     }
     
-    void RSGISCalcClusterPxlValueStdDev::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISCalcClusterPxlValueStdDev::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) 
     {
         if(intBandValues[ratBand-1] > 0)
         {
@@ -1330,16 +1356,24 @@ namespace rsgis{namespace rastergis{
             {
                 if((boost::math::isfinite)(floatBandValues[(*iterBands)->band-1]))
                 {
-                    if((*iterBands)->calcStdDev)
+                    bool useVal = true;
+                    if(this->use_no_data_vals[(*iterBands)->band-1] && (this->no_data_vals[(*iterBands)->band-1] == floatBandValues[(*iterBands)->band-1]))
                     {
-                        double stdDevComp = pow(((double)(floatBandValues[(*iterBands)->band-1] - statsData[fid][(*iterBands)->meanLocalIdx])), 2.0);
-                        if(firstVal[fid])
+                        useVal = false;
+                    }
+                    if(useVal)
+                    {
+                        if((*iterBands)->calcStdDev)
                         {
-                            stdDevData[fid][(*iterBands)->stdDevLocalIdx] = stdDevComp;
-                        }
-                        else
-                        {
-                            stdDevData[fid][(*iterBands)->stdDevLocalIdx] += stdDevComp;
+                            double stdDevComp = pow(((double)(floatBandValues[(*iterBands)->band-1] - statsData[fid][(*iterBands)->meanLocalIdx])), 2.0);
+                            if(firstVal[fid])
+                            {
+                                stdDevData[fid][(*iterBands)->stdDevLocalIdx] = stdDevComp;
+                            }
+                            else
+                            {
+                                stdDevData[fid][(*iterBands)->stdDevLocalIdx] += stdDevComp;
+                            }
                         }
                     }
                 }
@@ -1371,7 +1405,7 @@ namespace rsgis{namespace rastergis{
         this->useNoDataVal = useNoDataVal;
     }
 
-    void RSGISCalcClusterPxlValueHistograms::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISCalcClusterPxlValueHistograms::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) 
     {
         if(intBandValues[ratBand-1] > 0)
         {
@@ -1439,7 +1473,7 @@ namespace rsgis{namespace rastergis{
         this->ratBand = ratBand;
     }
     
-    void RSGISCalcClusterPxlValueStatsMeanLit::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISCalcClusterPxlValueStatsMeanLit::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) 
     {
         if(intBandValues[ratBand-1] > 0)
         {
@@ -1527,7 +1561,7 @@ namespace rsgis{namespace rastergis{
         this->ratBand = ratBand;
     }
     
-    void RSGISCalcClusterPxlValueStdDevMeanLit::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISCalcClusterPxlValueStdDevMeanLit::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) 
     {
         if(intBandValues[ratBand-1] > 0)
         {
@@ -1579,7 +1613,7 @@ namespace rsgis{namespace rastergis{
         this->band = band;
     }
     
-    void RSGISCalcImageMinMaxIntVals::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISCalcImageMinMaxIntVals::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) 
     {
         if(numIntVals == 0)
         {
@@ -1634,7 +1668,7 @@ namespace rsgis{namespace rastergis{
         this->noDataVal = noDataVal;
     }
     
-    void RSGISCalcClusterModeHistograms::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISCalcClusterModeHistograms::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) 
     {
         if(numIntVals == 0)
         {
@@ -1686,7 +1720,7 @@ namespace rsgis{namespace rastergis{
         this->ratBandIdx = ratBandIdx;
     }
     
-    void RSGISCalcCountValidPxlValues::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISCalcCountValidPxlValues::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) 
     {
         if(intBandValues[ratBandIdx] > 0)
         {
