@@ -44,7 +44,7 @@ namespace rsgis{namespace reg{
 		this->finaliseRegistration();
 	}
 	
-	void RSGISImageRegistration::findOverlap() throw(RSGISRegistrationException)
+	void RSGISImageRegistration::findOverlap()
 	{
 		try 
 		{
@@ -97,7 +97,7 @@ namespace rsgis{namespace reg{
 		overlapDefined = true;
 	}
 	
-	void RSGISImageRegistration::defineFirstTiePoint(unsigned int *startXOff, unsigned int *startYOff, unsigned int numXPts, unsigned int numYPts, unsigned int gap) throw(RSGISRegistrationException)
+	void RSGISImageRegistration::defineFirstTiePoint(unsigned int *startXOff, unsigned int *startYOff, unsigned int numXPts, unsigned int numYPts, unsigned int gap)
 	{
 		if(!overlapDefined)
 		{
@@ -114,7 +114,7 @@ namespace rsgis{namespace reg{
 
 	}
 	
-	float RSGISImageRegistration::findTiePointLocation(TiePoint *tiePt, unsigned int windowSize, unsigned int searchArea, RSGISImageSimilarityMetric *metric, float metricThreshold, unsigned int subPixelResolution, float *moveInX, float *moveInY) throw(RSGISRegistrationException)
+	float RSGISImageRegistration::findTiePointLocation(TiePoint *tiePt, unsigned int windowSize, unsigned int searchArea, RSGISImageSimilarityMetric *metric, float metricThreshold, unsigned int subPixelResolution, float *moveInX, float *moveInY)
 	{
 		float distanceMoved = 0;
 		
@@ -137,11 +137,11 @@ namespace rsgis{namespace reg{
 			double windowXWidth = (((double)windowSize)*overlap->xRes);
 			double windowYHeight = (((double)windowSize)*overlap->yRes);
 			
-			geos::geom::Envelope *env = new geos::geom::Envelope();
-			env->init((tiePt->eastings - windowXWidth), 
-					  (tiePt->eastings + windowXWidth + overlap->xRes), 
-					  (tiePt->northings - windowYHeight),
-					  (tiePt->northings + windowYHeight + +overlap->yRes));
+			OGREnvelope *env = new OGREnvelope();
+			env->MinX = (tiePt->eastings - windowXWidth);
+			env->MaxX = (tiePt->eastings + windowXWidth + overlap->xRes);
+			env->MinY = (tiePt->northings - windowYHeight);
+			env->MaxY = (tiePt->northings + windowYHeight + overlap->yRes);
 			
 			unsigned int numSearchPoints = (searchArea*2)+1;
 			float **imageSimilarity = new float*[numSearchPoints];
@@ -177,8 +177,6 @@ namespace rsgis{namespace reg{
             // Remainder for heighest metric
             float currentRemainderX = 0;
             float currentRemainderY = 0;
-            
-            
 			
             // Move floating window over search space
 			for(int yShift = yShiftStart; yShift <= yShiftEnd; ++yShift)
@@ -411,7 +409,7 @@ namespace rsgis{namespace reg{
 		return distanceMoved;
 	}
     
-    float RSGISImageRegistration::findTiePointLocation(TiePoint *tiePt, unsigned int windowSize, unsigned int searchArea, RSGISImageSimilarityMetric *metric, unsigned int subPixelResolution, float *moveInX, float *moveInY) throw(RSGISRegistrationException)
+    float RSGISImageRegistration::findTiePointLocation(TiePoint *tiePt, unsigned int windowSize, unsigned int searchArea, RSGISImageSimilarityMetric *metric, unsigned int subPixelResolution, float *moveInX, float *moveInY)
 	{
 		float distanceMoved = 0;
 		
@@ -433,12 +431,12 @@ namespace rsgis{namespace reg{
 			
 			double windowXWidth = (((double)windowSize)*overlap->xRes);
 			double windowYHeight = (((double)windowSize)*overlap->yRes);
-			
-			geos::geom::Envelope *env = new geos::geom::Envelope();
-			env->init((tiePt->eastings - windowXWidth),
-					  (tiePt->eastings + windowXWidth + overlap->xRes),
-					  (tiePt->northings - windowYHeight),
-					  (tiePt->northings + windowYHeight + +overlap->yRes));
+
+            OGREnvelope *env = new OGREnvelope();
+            env->MinX = (tiePt->eastings - windowXWidth);
+            env->MaxX = (tiePt->eastings + windowXWidth + overlap->xRes);
+            env->MinY = (tiePt->northings - windowYHeight);
+            env->MaxY = (tiePt->northings + windowYHeight + overlap->yRes);
 			
 			unsigned int numSearchPoints = (searchArea*2)+1;
 			float **imageSimilarity = new float*[numSearchPoints];
@@ -710,7 +708,7 @@ namespace rsgis{namespace reg{
             
             // Predict coresponding y value.
             double yPredicted = 0;
-			for(unsigned int j = 0; j < order ; j++)
+			for(unsigned int j = 0; j < order; j++)
 			{
 				double xPow = pow(extremeX, static_cast<int>(j)); // x^n;
 				double coeff = gsl_vector_get(coefficients, j); // a_n
@@ -732,7 +730,7 @@ namespace rsgis{namespace reg{
             
             // Predict coresponding y value.
             double yPredicted1 = 0;
-			for(unsigned int j = 0; j < order ; j++)
+			for(unsigned int j = 0; j < order; j++)
 			{
 				double xPow = pow(xValue1, static_cast<int>(j)); // x^n;
 				double coeff = gsl_vector_get(coefficients, j); // a_n
@@ -741,7 +739,7 @@ namespace rsgis{namespace reg{
 			}
             
             double yPredicted2 = 0;
-			for(unsigned int j = 0; j < order ; j++)
+			for(unsigned int j = 0; j < order; j++)
 			{
 				double xPow = pow(xValue2, static_cast<int>(j)); // x^n;
 				double coeff = gsl_vector_get(coefficients, j); // a_n
@@ -766,7 +764,7 @@ namespace rsgis{namespace reg{
                 {
                     xValue = minRange + (i*division);
                     yPredicted = 0;
-                    for(unsigned int j = 0; j < order ; j++)
+                    for(unsigned int j = 0; j < order; j++)
                     {
                         double xPow = pow(xValue, static_cast<int>(j)); // x^n;
                         double coeff = gsl_vector_get(coefficients, j); // a_n
@@ -799,7 +797,7 @@ namespace rsgis{namespace reg{
             {
 			xValue = minRange + (i*division);
 			yPredicted = 0;
-			for(unsigned int j = 0; j < order ; j++)
+			for(unsigned int j = 0; j < order; j++)
 			{
 				double xPow = pow(xValue, static_cast<int>(j)); // x^n;
 				double coeff = gsl_vector_get(coefficients, j); // a_n
@@ -829,7 +827,7 @@ namespace rsgis{namespace reg{
 		return extremeX;
 	}
 	
-    void RSGISImageRegistration::getImageOverlapFloat(GDALDataset **datasets, int numDS,  float **dsOffsets, int *width, int *height, double *gdalTransform) throw(RSGISRegistrationException)
+    void RSGISImageRegistration::getImageOverlapFloat(GDALDataset **datasets, int numDS,  float **dsOffsets, int *width, int *height, double *gdalTransform)
 	{
         /**
          Get the overlap of two images. Like getImageOverlap in image utils, however the offsets are retured as floats.
@@ -1025,7 +1023,7 @@ namespace rsgis{namespace reg{
 		}
 	}
     
-    void RSGISImageRegistration::getImageOverlapWithFloatShift(float xShift, float yShift, int **dsOffsets, int *width, int *height, double *gdalTransform, geos::geom::Envelope *env, float *remainderX, float *remainderY) throw(RSGISRegistrationException)
+    void RSGISImageRegistration::getImageOverlapWithFloatShift(float xShift, float yShift, int **dsOffsets, int *width, int *height, double *gdalTransform, OGREnvelope *env, float *remainderX, float *remainderY)
 	{
 		if(!overlapDefined)
 		{
@@ -1113,31 +1111,36 @@ namespace rsgis{namespace reg{
 			}
 			
 			// Check whether the overlapping region intersects within the Envelop
-			geos::geom::Envelope overlapEnv = geos::geom::Envelope(tlX, brX, brY, tlY);
-			if(!env->intersects(&overlapEnv))
+            OGREnvelope overlapEnv = OGREnvelope();
+            overlapEnv.MinX = tlX;
+            overlapEnv.MaxX = brX;
+            overlapEnv.MinY = brY;
+            overlapEnv.MaxY = tlY;
+
+			if(!env->Intersects(overlapEnv))
 			{
 				throw RSGISRegistrationException("The overlapping region of the images does not intersect with the envelop provided");
 			}
 			
 			// Trim to region overlapping with the envelop
-			if(tlX < env->getMinX())
+			if(tlX < env->MinX)
 			{
-				tlX = env->getMinX();
+				tlX = env->MinX;
 			}
 			
-			if(tlY > env->getMaxY())
+			if(tlY > env->MaxY)
 			{
-				tlY = env->getMaxY();
+				tlY = env->MaxY;
 			}
 			
-			if(brX > env->getMaxX())
+			if(brX > env->MaxX)
 			{
-				brX = env->getMaxX();
+				brX = env->MaxX;
 			}
 			
-			if(brY < env->getMinY())
+			if(brY < env->MinY)
 			{
-				brY = env->getMinY();
+				brY = env->MinY;
 			}
 
 			
@@ -1227,7 +1230,7 @@ namespace rsgis{namespace reg{
 		double windowXWidth = (((double)windowSize)*overlap->xRes);
 		double windowYHeight = (((double)windowSize)*overlap->yRes);
 		
-		geos::geom::Envelope *env = new geos::geom::Envelope();
+		OGREnvelope *env = new OGREnvelope();
 		
 		float **refDataBlock = NULL;
 		float **floatDataBlock = NULL;
@@ -1246,10 +1249,10 @@ namespace rsgis{namespace reg{
 			std::list<TiePoint*>::iterator iterTiePts;
 			for(iterTiePts = tiePts->begin(); iterTiePts != tiePts->end(); )
 			{
-				env->init(((*iterTiePts)->eastings - windowXWidth), 
-						  ((*iterTiePts)->eastings + windowXWidth + overlap->xRes), 
-						  ((*iterTiePts)->northings - windowYHeight),
-						  ((*iterTiePts)->northings + windowYHeight + +overlap->yRes));
+                env->MinX = ((*iterTiePts)->eastings - windowXWidth);
+                env->MaxX = ((*iterTiePts)->eastings + windowXWidth + overlap->xRes);
+                env->MinY = ((*iterTiePts)->northings - windowYHeight);
+                env->MaxY = ((*iterTiePts)->northings + windowYHeight + +overlap->yRes);
 				
 				this->getImageOverlapWithFloatShift(0, 0, dsOffsets, &overlapWidth, &overlapHeight, overlapTransform, env, &remainderX, &remainderY);
 				
@@ -1349,7 +1352,7 @@ namespace rsgis{namespace reg{
 		return stdDev;
 	}
 	
-	void RSGISImageRegistration::exportTiePointsENVIImage2MapImpl(std::string filepath, std::list<TiePoint*> *tiePts) throw(RSGISRegistrationException)
+	void RSGISImageRegistration::exportTiePointsENVIImage2MapImpl(std::string filepath, std::list<TiePoint*> *tiePts)
 	{
         std::ofstream outPtsFile(filepath.c_str(), std::ios::out | std::ios::trunc);
 		
@@ -1382,7 +1385,7 @@ namespace rsgis{namespace reg{
 		outPtsFile.close();
 	}
 	
-	void RSGISImageRegistration::exportTiePointsENVIImage2ImageImpl(std::string filepath, std::list<TiePoint*> *tiePts) throw(RSGISRegistrationException)
+	void RSGISImageRegistration::exportTiePointsENVIImage2ImageImpl(std::string filepath, std::list<TiePoint*> *tiePts)
 	{
         std::ofstream outPtsFile(filepath.c_str(), std::ios::out | std::ios::trunc);
 		
@@ -1415,7 +1418,7 @@ namespace rsgis{namespace reg{
 		outPtsFile.close();
 	}
 	
-	void RSGISImageRegistration::exportTiePointsRSGISImage2MapImpl(std::string filepath, std::list<TiePoint*> *tiePts) throw(RSGISRegistrationException)
+	void RSGISImageRegistration::exportTiePointsRSGISImage2MapImpl(std::string filepath, std::list<TiePoint*> *tiePts)
 	{
 		std::ofstream outPtsFile(filepath.c_str(), std::ios::out | std::ios::trunc);
 		
@@ -1449,7 +1452,7 @@ namespace rsgis{namespace reg{
 		outPtsFile.close();
 	}
     
-    void RSGISImageRegistration::exportTiePointsRSGISMapOffsImpl(std::string filepath, std::list<TiePoint*> *tiePts)throw(RSGISRegistrationException)
+    void RSGISImageRegistration::exportTiePointsRSGISMapOffsImpl(std::string filepath, std::list<TiePoint*> *tiePts)
     {
         std::ofstream outPtsFile(filepath.c_str(), std::ios::out | std::ios::trunc);
 		
