@@ -29,7 +29,7 @@ namespace rsgis{namespace segment{
         
     }
     
-    void RSGISEliminateSinglePixels::eliminate(GDALDataset *inSpecData, GDALDataset *inClumpsData, GDALDataset *tmpData, std::string outputImage, float noDataVal, bool noDataValProvided, bool projFromImage, std::string proj, std::string format)throw(rsgis::img::RSGISImageCalcException)
+    void RSGISEliminateSinglePixels::eliminate(GDALDataset *inSpecData, GDALDataset *inClumpsData, GDALDataset *tmpData, std::string outputImage, float noDataVal, bool noDataValProvided, bool projFromImage, std::string proj, std::string format)
     {
         try
         {
@@ -92,7 +92,7 @@ namespace rsgis{namespace segment{
         }
     }
     
-    void RSGISEliminateSinglePixels::eliminateBlocks(GDALDataset *inSpecData, GDALDataset *inClumpsData, GDALDataset *tmpData, std::string outputImage, float noDataVal, bool noDataValProvided, bool projFromImage, std::string proj, std::string format)throw(rsgis::img::RSGISImageCalcException)
+    void RSGISEliminateSinglePixels::eliminateBlocks(GDALDataset *inSpecData, GDALDataset *inClumpsData, GDALDataset *tmpData, std::string outputImage, float noDataVal, bool noDataValProvided, bool projFromImage, std::string proj, std::string format)
     {
         try
         {
@@ -175,7 +175,7 @@ namespace rsgis{namespace segment{
         }
     }
     
-    unsigned long RSGISEliminateSinglePixels::findSinglePixels(GDALDataset *inClumpsData, GDALDataset *tmpData, float noDataVal, bool noDataValProvided) throw(rsgis::img::RSGISImageCalcException)
+    unsigned long RSGISEliminateSinglePixels::findSinglePixels(GDALDataset *inClumpsData, GDALDataset *tmpData, float noDataVal, bool noDataValProvided) 
     {
         unsigned long countSingles = 0;
         try 
@@ -193,16 +193,10 @@ namespace rsgis{namespace segment{
             unsigned int *outData = new unsigned int[width];
             bool notSingle = false;
             
-            int feedback = height/10;
-            int feedbackCounter = 0;
-            std::cout << "Started" << std::flush;
+            rsgis_tqdm pbar;
             for(unsigned int i = 0; i < height; ++i)
             {
-                if((i % feedback) == 0)
-                {
-                    std::cout << "." << feedbackCounter << "." << std::flush;
-                    feedbackCounter = feedbackCounter + 10;
-                }
+                pbar.progress(i, height);
                 if(i == 0)
                 {
                     clumpBand->RasterIO(GF_Read, 0, i, width, 1, inData[1], width, 1, GDT_UInt32, 0, 0);
@@ -432,7 +426,7 @@ namespace rsgis{namespace segment{
                 
                 tmpBand->RasterIO(GF_Write, 0, i, width, 1, outData, width, 1, GDT_UInt32, 0, 0);
             }
-            std::cout << ". Complete\n";
+            pbar.finish();
             
             delete[] inData[0];
             delete[] inData[1];
@@ -448,7 +442,7 @@ namespace rsgis{namespace segment{
         return countSingles;
     }
     
-    bool RSGISEliminateSinglePixels::eliminateSinglePixels(GDALDataset *inSpecData, GDALDataset *inClumpsData, GDALDataset *tmpData, GDALDataset *outDataset, float noDataVal, bool noDataValProvided) throw(rsgis::img::RSGISImageCalcException)
+    bool RSGISEliminateSinglePixels::eliminateSinglePixels(GDALDataset *inSpecData, GDALDataset *inClumpsData, GDALDataset *tmpData, GDALDataset *outDataset, float noDataVal, bool noDataValProvided) 
     {
         bool hasChangeOccured = false;
         try 
@@ -492,14 +486,10 @@ namespace rsgis{namespace segment{
             
             int feedback = height/10;
             int feedbackCounter = 0;
-            std::cout << "Started" << std::flush;
+            rsgis_tqdm pbar;
             for(unsigned int i = 0; i < height; ++i)
             {
-                if((i % feedback) == 0)
-                {
-                    std::cout << "." << feedbackCounter << "." << std::flush;
-                    feedbackCounter = feedbackCounter + 10;
-                }
+                pbar.progress(i, height);
                 if(i == 0)
                 {
                     clumpBand->RasterIO(GF_Read, 0, i, width, 1, inData[1], width, 1, GDT_UInt32, 0, 0);
@@ -1127,7 +1117,7 @@ namespace rsgis{namespace segment{
                 
                 outBand->RasterIO(GF_Write, 0, i, width, 1, outData, width, 1, GDT_UInt32, 0, 0);
             }
-            std::cout << ". Complete\n";
+            pbar.finish();
             
             delete[] inData[0];
             delete[] inData[1];
@@ -1187,7 +1177,7 @@ namespace rsgis{namespace segment{
         numSingles = 0;
     }
     
-    void RSGISFindSinglePixels::calcImageValue(float ***dataBlock, int numBands, int winSize, double *output) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISFindSinglePixels::calcImageValue(float ***dataBlock, int numBands, int winSize, double *output) 
     {
         try
         {
@@ -1262,7 +1252,7 @@ namespace rsgis{namespace segment{
         this->noDataValProvided = noDataValProvided;
     }
     
-    void RSGISElimSinglePixelsCalcImg::calcImageValue(float ***dataBlock, int numBands, int winSize, double *output) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISElimSinglePixelsCalcImg::calcImageValue(float ***dataBlock, int numBands, int winSize, double *output) 
     {
         try
         {
