@@ -30,7 +30,7 @@ namespace rsgis{namespace segment{
         
     }
     
-    void RSGISGenMeanSegImage::generateMeanImage(GDALDataset *spectral, GDALDataset *clumps, GDALDataset *meanImg) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISGenMeanSegImage::generateMeanImage(GDALDataset *spectral, GDALDataset *clumps, GDALDataset *meanImg) 
     {
         if((spectral->GetRasterXSize() != clumps->GetRasterXSize()) |
            (spectral->GetRasterXSize() != meanImg->GetRasterXSize()))
@@ -81,16 +81,10 @@ namespace rsgis{namespace segment{
         std::vector<float> *clumpSpecPxlVals = new std::vector<float>[numSpecBands];
         float *specPxlVals = new float[numSpecBands];
         
-        int feedback = height/10;
-        int feedbackCounter = 0;
-        std::cout << "Started" << std::flush;
+        rsgis_tqdm pbar;
         for(unsigned int i = 0; i < height; ++i)
         {
-            if((i % feedback) == 0)
-            {
-                std::cout << ".." << feedbackCounter << ".." << std::flush;
-                feedbackCounter = feedbackCounter + 10;
-            }
+            pbar.progress(i, height);
             
             for(unsigned int j = 0; j < width; ++j)
             {
@@ -238,7 +232,7 @@ namespace rsgis{namespace segment{
                 }
             }
         }
-        std::cout << " Complete.\n";
+        pbar.finish();
         
         delete[] clumpSpecPxlVals;
         delete[] specPxlVals;
@@ -252,7 +246,7 @@ namespace rsgis{namespace segment{
         delete[] pxlMask;
     }
     
-    void RSGISGenMeanSegImage::generateMeanImageUsingClumpTable(GDALDataset *spectral, GDALDataset *clumps, GDALDataset *meanImg) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISGenMeanSegImage::generateMeanImageUsingClumpTable(GDALDataset *spectral, GDALDataset *clumps, GDALDataset *meanImg) 
     {
         if((spectral->GetRasterXSize() != clumps->GetRasterXSize()) |
            (spectral->GetRasterXSize() != meanImg->GetRasterXSize()))
@@ -401,7 +395,7 @@ namespace rsgis{namespace segment{
         delete clumpTab;
     }
     
-    void RSGISGenMeanSegImage::generateMeanImageUsingCalcImage(GDALDataset *spectral, GDALDataset *clumps, GDALDataset *meanImg) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISGenMeanSegImage::generateMeanImageUsingCalcImage(GDALDataset *spectral, GDALDataset *clumps, GDALDataset *meanImg) 
     {
         try
         {
@@ -513,7 +507,7 @@ namespace rsgis{namespace segment{
         this->numClumps = numClumps;
     }
     
-    void RSGISPopulateMeans::calcImageValue(float *bandValues, int numBands) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISPopulateMeans::calcImageValue(float *bandValues, int numBands) 
     {
         try
         {
@@ -567,7 +561,7 @@ namespace rsgis{namespace segment{
         this->numClumps = numClumps;
     }
     
-    void RSGISApplyMeans2Output::calcImageValue(float *bandValues, int numBands, double *output) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISApplyMeans2Output::calcImageValue(float *bandValues, int numBands, double *output) 
     {
         try
         {
