@@ -29,7 +29,7 @@ namespace rsgis{namespace segment{
         
     }
     
-    void RSGISMergeSegmentationTiles::createTileBorderClumpMask(GDALDataset *borderMaskDataset, std::vector<std::string> inputImagePaths, unsigned int tileBoundary, unsigned int tileOverlap, unsigned int tileBody, std::string colsName) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISMergeSegmentationTiles::createTileBorderClumpMask(GDALDataset *borderMaskDataset, std::vector<std::string> inputImagePaths, unsigned int tileBoundary, unsigned int tileOverlap, unsigned int tileBody, std::string colsName) 
     {
         try
         {
@@ -88,7 +88,7 @@ namespace rsgis{namespace segment{
         }
     }
     
-    void RSGISMergeSegmentationTiles::mergeClumpBodies(GDALDataset *outputDataset, GDALDataset *borderMaskDataset, std::vector<std::string> inputImagePaths, unsigned int tileBoundary, unsigned int tileOverlap, unsigned int tileBody, std::string colsName) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISMergeSegmentationTiles::mergeClumpBodies(GDALDataset *outputDataset, GDALDataset *borderMaskDataset, std::vector<std::string> inputImagePaths, unsigned int tileBoundary, unsigned int tileOverlap, unsigned int tileBody, std::string colsName) 
     {
         try
         {
@@ -153,7 +153,7 @@ namespace rsgis{namespace segment{
         }
     }
     
-    void RSGISMergeSegmentationTiles::mergeClumpImages(GDALDataset *outputDataset, std::vector<std::string> inputImagePaths, bool mergeRATs) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISMergeSegmentationTiles::mergeClumpImages(GDALDataset *outputDataset, std::vector<std::string> inputImagePaths, bool mergeRATs) 
     {
         try
         {
@@ -266,7 +266,7 @@ namespace rsgis{namespace segment{
         }
     }
     
-    size_t RSGISMergeSegmentationTiles::numberBodyClumps(GDALRasterAttributeTable *gdalATT, std::string outColName, std::string clumpPosColName, int tileBody, size_t clumpsOffset) throw(RSGISException)
+    size_t RSGISMergeSegmentationTiles::numberBodyClumps(GDALRasterAttributeTable *gdalATT, std::string outColName, std::string clumpPosColName, int tileBody, size_t clumpsOffset)
     {
         size_t numBodyClumps = 0;
         try
@@ -308,7 +308,7 @@ namespace rsgis{namespace segment{
         return numBodyClumps;
     }
     
-    size_t RSGISMergeSegmentationTiles::numberClumps(GDALRasterAttributeTable *gdalATT, std::string outColName, size_t clumpsOffset) throw(RSGISException)
+    size_t RSGISMergeSegmentationTiles::numberClumps(GDALRasterAttributeTable *gdalATT, std::string outColName, size_t clumpsOffset)
     {
         rsgis::rastergis::RSGISRasterAttUtils attUtils;
         size_t numClumps = 0;
@@ -339,7 +339,7 @@ namespace rsgis{namespace segment{
         return numClumps;
     }
     
-    void RSGISMergeSegmentationTiles::addTileBodyClumps(GDALDataset *outputDataset, GDALDataset *tileDataset, GDALDataset *borderMaskDataset, GDALRasterAttributeTable *gdalATT, std::string outClumpIDColName, std::string clumpPosColName, unsigned int tileBody, unsigned int tileBoundary) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISMergeSegmentationTiles::addTileBodyClumps(GDALDataset *outputDataset, GDALDataset *tileDataset, GDALDataset *borderMaskDataset, GDALRasterAttributeTable *gdalATT, std::string outClumpIDColName, std::string clumpPosColName, unsigned int tileBody, unsigned int tileBoundary) 
     {
         rsgis::img::RSGISImageUtils imgUtils;
         try
@@ -394,9 +394,7 @@ namespace rsgis{namespace segment{
             int *clumpIdVals = attUtils.readIntColumn(gdalATT, outClumpIDColName, &numRows);
             size_t fid = 0;
             
-			int feedback = height/10;
-			int feedbackCounter = 0;
-			std::cout << "Started" << std::flush;
+			rsgis_tqdm pbar;
 			// Loop images to process data
 			for(int i = 0; i < nYBlocks; i++)
 			{
@@ -409,11 +407,7 @@ namespace rsgis{namespace segment{
                 
                 for(int m = 0; m < yBlockSize; ++m)
                 {
-                    if((feedback != 0) && ((((i*yBlockSize)+m) % feedback) == 0))
-                    {
-                        std::cout << "." << feedbackCounter << "." << std::flush;
-                        feedbackCounter = feedbackCounter + 10;
-                    }
+                    pbar.progress((i*yBlockSize)+m, height);
                     
                     for(int j = 0; j < width; j++)
                     {
@@ -470,11 +464,7 @@ namespace rsgis{namespace segment{
                 
                 for(int m = 0; m < remainRows; ++m)
                 {
-                    if((feedback != 0) && ((((nYBlocks*yBlockSize)+m) % feedback) == 0))
-                    {
-                        std::cout << "." << feedbackCounter << "." << std::flush;
-                        feedbackCounter = feedbackCounter + 10;
-                    }
+                    pbar.progress((nYBlocks*yBlockSize)+m, height);
                     
                     for(int j = 0; j < width; j++)
                     {
@@ -517,7 +507,7 @@ namespace rsgis{namespace segment{
                 rowOffset = maskOffset[1] + (yBlockSize * nYBlocks);
                 maskBand->RasterIO(GF_Write, maskOffset[0], rowOffset, width, remainRows, imgMaskData, width, remainRows, GDT_UInt32, 0, 0);
             }
-            std::cout << " Complete.\n";
+            pbar.finish();
             
             CPLFree(imgInData);
             CPLFree(imgOutData);
@@ -556,7 +546,7 @@ namespace rsgis{namespace segment{
         }
     }
     
-    void RSGISMergeSegmentationTiles::addTileBorder2Mask(GDALDataset *tileDataset, GDALDataset *borderMaskDataset, GDALRasterAttributeTable *gdalATT, std::string clumpPosColName, unsigned int tileBoundary) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISMergeSegmentationTiles::addTileBorder2Mask(GDALDataset *tileDataset, GDALDataset *borderMaskDataset, GDALRasterAttributeTable *gdalATT, std::string clumpPosColName, unsigned int tileBoundary) 
     {
         rsgis::img::RSGISImageUtils imgUtils;
         try
@@ -603,9 +593,7 @@ namespace rsgis{namespace segment{
             int *posVals = attUtils.readIntColumn(gdalATT, clumpPosColName, &numRows);
             size_t fid = 0;
             
-			int feedback = height/10;
-			int feedbackCounter = 0;
-			std::cout << "Started" << std::flush;
+			rsgis_tqdm pbar;
 			// Loop images to process data
 			for(int i = 0; i < nYBlocks; i++)
 			{
@@ -616,11 +604,7 @@ namespace rsgis{namespace segment{
                 
                 for(int m = 0; m < yBlockSize; ++m)
                 {
-                    if((feedback != 0) && ((((i*yBlockSize)+m) % feedback) == 0))
-                    {
-                        std::cout << "." << feedbackCounter << "." << std::flush;
-                        feedbackCounter = feedbackCounter + 10;
-                    }
+                    pbar.progress((i*yBlockSize)+m, height);
                     
                     for(int j = 0; j < width; j++)
                     {
@@ -668,11 +652,7 @@ namespace rsgis{namespace segment{
                 
                 for(int m = 0; m < remainRows; ++m)
                 {
-                    if((feedback != 0) && ((((nYBlocks*yBlockSize)+m) % feedback) == 0))
-                    {
-                        std::cout << "." << feedbackCounter << "." << std::flush;
-                        feedbackCounter = feedbackCounter + 10;
-                    }
+                    pbar.progress((nYBlocks*yBlockSize)+m, height);
                     
                     for(int j = 0; j < width; j++)
                     {
@@ -709,7 +689,7 @@ namespace rsgis{namespace segment{
                 rowOffset = maskOffset[1] + (yBlockSize * nYBlocks);
                 maskBand->RasterIO(GF_Write, maskOffset[0], rowOffset, width, remainRows, imgMaskData, width, remainRows, GDT_UInt32, 0, 0);
             }
-            std::cout << " Complete.\n";
+            pbar.finish();
             
             CPLFree(imgInData);
             CPLFree(imgMaskData);
@@ -745,7 +725,7 @@ namespace rsgis{namespace segment{
         }
     }
     
-    void RSGISMergeSegmentationTiles::addImageClumps(GDALDataset *outputDataset, GDALDataset *clumpsDataset, GDALRasterAttributeTable *gdalATT, std::string outClumpIDColName) throw(rsgis::img::RSGISImageCalcException)
+    void RSGISMergeSegmentationTiles::addImageClumps(GDALDataset *outputDataset, GDALDataset *clumpsDataset, GDALRasterAttributeTable *gdalATT, std::string outClumpIDColName) 
     {
         rsgis::img::RSGISImageUtils imgUtils;
         try
@@ -792,9 +772,7 @@ namespace rsgis{namespace segment{
             int *clumpIdVals = attUtils.readIntColumn(gdalATT, outClumpIDColName, &numRows);
             size_t fid = 0;
             
-			int feedback = height/10;
-			int feedbackCounter = 0;
-			std::cout << "Started" << std::flush;
+			rsgis_tqdm pbar;
 			// Loop images to process data
 			for(int i = 0; i < nYBlocks; i++)
 			{
@@ -805,11 +783,7 @@ namespace rsgis{namespace segment{
                 
                 for(int m = 0; m < yBlockSize; ++m)
                 {
-                    if((feedback != 0) && ((((i*yBlockSize)+m) % feedback) == 0))
-                    {
-                        std::cout << "." << feedbackCounter << "." << std::flush;
-                        feedbackCounter = feedbackCounter + 10;
-                    }
+                    pbar.progress((i*yBlockSize)+m, height);
                     
                     for(int j = 0; j < width; j++)
                     {
@@ -855,11 +829,7 @@ namespace rsgis{namespace segment{
                 
                 for(int m = 0; m < remainRows; ++m)
                 {
-                    if((feedback != 0) && ((((nYBlocks*yBlockSize)+m) % feedback) == 0))
-                    {
-                        std::cout << "." << feedbackCounter << "." << std::flush;
-                        feedbackCounter = feedbackCounter + 10;
-                    }
+                    pbar.progress((nYBlocks*yBlockSize)+m, height);
                     
                     for(int j = 0; j < width; j++)
                     {
@@ -893,7 +863,7 @@ namespace rsgis{namespace segment{
                 rowOffset = outOffset[1] + (yBlockSize * nYBlocks);
                 outputBand->RasterIO(GF_Write, outOffset[0], rowOffset, width, remainRows, imgOutData, width, remainRows, GDT_UInt32, 0, 0);
             }
-            std::cout << " Complete.\n";
+            pbar.finish();
             
             CPLFree(imgInData);
             CPLFree(imgOutData);
